@@ -46,8 +46,7 @@ static unsigned ReadFullTOCSony __PR(( SCSI *scgp ));
 static unsigned ReadFullTOCMMC __PR(( SCSI *scgp ));
 
 
-int SCSI_emulated_ATAPI_on(scgp)
-	SCSI *scgp;
+int SCSI_emulated_ATAPI_on(SCSI *scgp)
 {
 /*	return is_atapi;*/
 	if (scg_isatapi(scgp) > 0)
@@ -57,8 +56,7 @@ int SCSI_emulated_ATAPI_on(scgp)
 	return (allow_atapi(scgp, TRUE));
 }
 
-int heiko_mmc(scgp)
-	SCSI *scgp;
+int heiko_mmc(SCSI *scgp)
 {
         unsigned char	mode[0x100];
 	int		was_atapi;
@@ -92,11 +90,7 @@ unsigned char orgmode10, orgmode11;
 
 /* get current sector size from SCSI cdrom drive */
 unsigned int 
-get_orig_sectorsize(scgp, m4, m10, m11)
-	SCSI *scgp;
-	unsigned char *m4;
-	unsigned char *m10; 
-	unsigned char *m11;
+get_orig_sectorsize(SCSI *scgp, unsigned char *m4, unsigned char *m10, unsigned char *m11)
 {
       /* first get current values for density, etc. */
 
@@ -132,9 +126,7 @@ get_orig_sectorsize(scgp, m4, m10, m11)
 
 
 /* switch CDROM scsi drives to given sector size  */
-int set_sectorsize (scgp, secsize)
-	SCSI *scgp;
-	unsigned int secsize;
+int set_sectorsize (SCSI *scgp, unsigned int secsize)
 {
   static unsigned char mode [4 + 8];
   int retval;
@@ -163,9 +155,7 @@ int set_sectorsize (scgp, secsize)
 
 
 /* switch Toshiba/DEC and HP drives from/to cdda density */
-void EnableCddaModeSelect (scgp, fAudioMode)
-	SCSI *scgp;
-	int fAudioMode;
+void EnableCddaModeSelect (SCSI *scgp, int fAudioMode)
 {
   /* reserved, Medium type=0, Dev spec Parm = 0, block descriptor len 0 oder 8,
      Density (cd format) 
@@ -215,8 +205,7 @@ void EnableCddaModeSelect (scgp, fAudioMode)
 
 
 /* read CD Text information from the table of contents */
-void ReadTocTextSCSIMMC ( scgp )
-	SCSI *scgp;
+void ReadTocTextSCSIMMC ( SCSI *scgp )
 {
     short datalength;
     unsigned char *p = bufferTOC;
@@ -296,8 +285,7 @@ fprintf(stderr, "read %d bytes. sizeof(bufferTOC)=%u\n", read_, CD_FRAMESIZE);
 }
 
 /* read the full TOC */
-static unsigned ReadFullTOCSony ( scgp )
-	SCSI *scgp;
+static unsigned ReadFullTOCSony ( SCSI *scgp )
 {
   /* READTOC, MSF, format, res, res, res, Start track/session, len msb,
      len lsb, control */
@@ -333,8 +321,7 @@ static unsigned ReadFullTOCSony ( scgp )
 }
 
 /* read the table of contents from the cd and fill the TOC array */
-unsigned ReadTocSony ( scgp )
-	SCSI *scgp;
+unsigned ReadTocSony ( SCSI *scgp )
 {
 	unsigned tracks;
 	unsigned return_length;
@@ -489,8 +476,7 @@ fprintf(stderr, "%02x %02x %02x %02x %02x\n"
 }
 
 /* read the start of the lead-out from the first session TOC */
-unsigned ReadFirstSessionTOCSony ( scgp )
-	SCSI *scgp;
+unsigned ReadFirstSessionTOCSony ( SCSI *scgp )
 {
 	unsigned return_length;
 	return_length = ReadFullTOCSony(scgp);
@@ -521,8 +507,7 @@ unsigned ReadFirstSessionTOCSony ( scgp )
 }
 
 /* read the full TOC */
-static unsigned ReadFullTOCMMC ( scgp )
-	SCSI *scgp;
+static unsigned ReadFullTOCMMC ( SCSI *scgp )
 {
 
   /* READTOC, MSF, format, res, res, res, Start track/session, len msb,
@@ -562,8 +547,7 @@ static unsigned ReadFullTOCMMC ( scgp )
 }
 
 /* read the start of the lead-out from the first session TOC */
-unsigned ReadFirstSessionTOCMMC ( scgp )
-	SCSI *scgp;
+unsigned ReadFirstSessionTOCMMC ( SCSI *scgp )
 {
         unsigned off;
 	unsigned return_length;
@@ -583,8 +567,7 @@ unsigned ReadFirstSessionTOCMMC ( scgp )
 }
 
 /* read the table of contents from the cd and fill the TOC array */
-unsigned ReadTocMMC ( scgp )
-	SCSI *scgp;
+unsigned ReadTocMMC ( SCSI *scgp )
 {
 	unsigned tracks;
 	unsigned return_length;
@@ -717,8 +700,7 @@ fprintf(stderr, "%02x %02x %02x %02x %02x\n"
 }
 
 /* read the table of contents from the cd and fill the TOC array */
-unsigned ReadTocSCSI ( scgp )
-	SCSI *scgp;
+unsigned ReadTocSCSI ( SCSI *scgp )
 {
     unsigned tracks;
     int	result;
@@ -805,11 +787,7 @@ unsigned ReadTocSCSI ( scgp )
 
 /* Read max. SectorBurst of cdda sectors to buffer
    via standard SCSI-2 Read(10) command */
-int ReadStandard (scgp, p, lSector, SectorBurstVal )
-	SCSI *scgp;
-	UINT4 *p;
-	unsigned lSector;
-	unsigned SectorBurstVal;
+int ReadStandard (SCSI *scgp, UINT4 *p, unsigned lSector, unsigned SectorBurstVal )
 {
   /* READ10, flags, block1 msb, block2, block3, block4 lsb, reserved, 
      transfer len msb, transfer len lsb, block addressing mode */
@@ -838,11 +816,7 @@ int ReadStandard (scgp, p, lSector, SectorBurstVal )
 
 /* Read max. SectorBurst of cdda sectors to buffer
    via vendor-specific ReadCdda(10) command */
-int ReadCdda10 (scgp, p, lSector, SectorBurstVal )
-	SCSI *scgp;
-	UINT4 *p;
-	unsigned lSector;
-	unsigned SectorBurstVal;
+int ReadCdda10 (SCSI *scgp, UINT4 *p, unsigned lSector, unsigned SectorBurstVal)
 {
   /* READ10, flags, block1 msb, block2, block3, block4 lsb, reserved, 
      transfer len msb, transfer len lsb, block addressing mode */
@@ -872,11 +846,7 @@ int ReadCdda10 (scgp, p, lSector, SectorBurstVal )
 
 /* Read max. SectorBurst of cdda sectors to buffer
    via vendor-specific ReadCdda(12) command */
-int ReadCdda12 (scgp, p, lSector, SectorBurstVal )
-	SCSI *scgp;
-	UINT4 *p;
-	unsigned lSector;
-	unsigned SectorBurstVal;
+int ReadCdda12 (SCSI *scgp, UINT4 *p, unsigned lSector, unsigned SectorBurstVal )
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
@@ -909,11 +879,7 @@ int ReadCdda12 (scgp, p, lSector, SectorBurstVal )
 > normal and the number of sectors is coded in Byte 8 and 9 (begining with 0).
 */
 
-int ReadCdda12Matsushita (scgp, p, lSector, SectorBurstVal )
-	SCSI *scgp;
-	UINT4 *p;
-	unsigned lSector;
-	unsigned SectorBurstVal;
+int ReadCdda12Matsushita (SCSI *scgp, UINT4 *p, unsigned lSector, unsigned SectorBurstVal )
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
@@ -941,11 +907,7 @@ int ReadCdda12Matsushita (scgp, p, lSector, SectorBurstVal )
 
 /* Read max. SectorBurst of cdda sectors to buffer
    via MMC standard READ CD command */
-int ReadCddaMMC12 (scgp, p, lSector, SectorBurstVal )
-	SCSI *scgp;
-	UINT4 *p;
-	unsigned lSector;
-	unsigned SectorBurstVal;
+int ReadCddaMMC12 (SCSI *scgp, UINT4 *p, unsigned lSector, unsigned SectorBurstVal )
 {
 	register struct	scg_cmd	*scmd;
 	scmd = scgp->scmd;
@@ -973,11 +935,7 @@ int ReadCddaMMC12 (scgp, p, lSector, SectorBurstVal )
 	return SectorBurstVal - scg_getresid(scgp)/CD_FRAMESIZE_RAW;
 }
 
-int ReadCddaFallbackMMC (scgp, p, lSector, SectorBurstVal )
-	SCSI *scgp;
-	UINT4 *p;
-	unsigned lSector;
-	unsigned SectorBurstVal;
+int ReadCddaFallbackMMC (SCSI *scgp, UINT4 *p, unsigned lSector, unsigned SectorBurstVal )
 {
 	static int ReadCdda12_unknown = 0;
 	int retval = -999;
@@ -1000,14 +958,7 @@ int ReadCddaFallbackMMC (scgp, p, lSector, SectorBurstVal )
 
 /* Read the Sub-Q-Channel to SubQbuffer. This is the method for
  * drives that do not support subchannel parameters. */
-#ifdef	PROTOTYPES
 static subq_chnl *ReadSubQFallback (SCSI *scgp, unsigned char sq_format, unsigned char track)
-#else
-static subq_chnl *ReadSubQFallback ( scgp, sq_format, track )
-	SCSI *scgp;
-	unsigned char sq_format;
-	unsigned char track;
-#endif
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
@@ -1046,14 +997,7 @@ static subq_chnl *ReadSubQFallback ( scgp, sq_format, track )
 }
 
 /* Read the Sub-Q-Channel to SubQbuffer */
-#ifdef	PROTOTYPES
 subq_chnl *ReadSubQSCSI (SCSI *scgp, unsigned char sq_format, unsigned char track)
-#else
-subq_chnl *ReadSubQSCSI ( scgp, sq_format, track )
-	SCSI *scgp;
-	unsigned char sq_format;
-	unsigned char track;
-#endif
 {
         int resp_size;
 	register struct	scg_cmd	*scmd = scgp->scmd;
@@ -1103,9 +1047,7 @@ subq_chnl *ReadSubQSCSI ( scgp, sq_format, track )
 
 /********* non standardized speed selects ***********************/
 
-void SpeedSelectSCSIToshiba (scgp, speed)
-	SCSI *scgp;
-	unsigned speed;
+void SpeedSelectSCSIToshiba (SCSI *scgp, unsigned speed)
 {
   static unsigned char mode [4 + 3];
   unsigned char *page = mode + 4;
@@ -1126,9 +1068,7 @@ void SpeedSelectSCSIToshiba (scgp, speed)
   scgp->silent--;
 }
 
-void SpeedSelectSCSINEC (scgp, speed)
-	SCSI *scgp;
-	unsigned speed;
+void SpeedSelectSCSINEC (SCSI *scgp, unsigned speed)
 {
   static unsigned char mode [4 + 8];
   unsigned char *page = mode + 4;
@@ -1162,9 +1102,7 @@ void SpeedSelectSCSINEC (scgp, speed)
         fprintf(stderr ,"speed select NEC failed\n");
 }
 
-void SpeedSelectSCSIPhilipsCDD2600 (scgp, speed)
-	SCSI *scgp;
-	unsigned speed;
+void SpeedSelectSCSIPhilipsCDD2600 (SCSI *scgp, unsigned speed)
 {
   /* MODE_SELECT, page = SCSI-2  save page disabled, reserved, reserved,
      parm list len, flags */
@@ -1185,9 +1123,7 @@ void SpeedSelectSCSIPhilipsCDD2600 (scgp, speed)
         fprintf (stderr, "speed select PhilipsCDD2600 failed\n");
 }
 
-void SpeedSelectSCSISony (scgp, speed)
-	SCSI *scgp;
-	unsigned speed;
+void SpeedSelectSCSISony (SCSI *scgp, unsigned speed)
 {
   static unsigned char mode [4 + 4];
   unsigned char *page = mode + 4;
@@ -1207,9 +1143,7 @@ void SpeedSelectSCSISony (scgp, speed)
   scgp->silent--;
 }
 
-void SpeedSelectSCSIYamaha (scgp, speed)
-	SCSI *scgp;
-	unsigned speed;
+void SpeedSelectSCSIYamaha (SCSI *scgp, unsigned speed)
 {
   static unsigned char mode [4 + 4];
   unsigned char *page = mode + 4;
@@ -1227,9 +1161,7 @@ void SpeedSelectSCSIYamaha (scgp, speed)
         fprintf (stderr, "speed select Yamaha failed\n");
 }
 
-void SpeedSelectSCSIMMC (scgp, speed)
-	SCSI *scgp;
-	unsigned speed;
+void SpeedSelectSCSIMMC (SCSI *scgp, unsigned speed)
 {
   int spd;
 	register struct	scg_cmd	*scmd = scgp->scmd;
@@ -1267,8 +1199,7 @@ void SpeedSelectSCSIMMC (scgp, speed)
 }
 
 /* request vendor brand and model */
-unsigned char *Inquiry ( scgp )
-	SCSI *scgp;
+unsigned char *Inquiry ( SCSI *scgp )
 {
   static unsigned char *Inqbuffer = NULL;
 	register struct	scg_cmd	*scmd = scgp->scmd;
@@ -1315,8 +1246,7 @@ unsigned char *Inquiry ( scgp )
 #define NO_MEDIA_SC 0x3a
 #define NO_MEDIA_SCQ 0x00
 
-int TestForMedium ( scgp )
-	SCSI *scgp;
+int TestForMedium ( SCSI *scgp )
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
@@ -1356,32 +1286,28 @@ int TestForMedium ( scgp )
   }
 }
 
-int StopPlaySCSI ( scgp )
-	SCSI *scgp;
+int StopPlaySCSI ( SCSI *scgp )
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
 	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
-  scmd->addr = NULL;
-  scmd->size = 0;
-  scmd->flags = SCG_DISRE_ENA;
-  scmd->cdb_len = SC_G0_CDBLEN;
-  scmd->sense_len = CCS_SENSE_LEN;
-  scmd->cdb.g0_cdb.cmd = 0x1b;
-  scmd->cdb.g0_cdb.lun = scg_lun(scgp);
+	scmd->addr = NULL;
+	scmd->size = 0;
+	scmd->flags = SCG_DISRE_ENA;
+	scmd->cdb_len = SC_G0_CDBLEN;
+	scmd->sense_len = CCS_SENSE_LEN;
+	scmd->cdb.g0_cdb.cmd = 0x1b;
+	scmd->cdb.g0_cdb.lun = scg_lun(scgp);
 
-  if (scgp->verbose) fprintf(stderr, "\nstop audio play");
-  /* do the scsi cmd */
+	if (scgp->verbose) fprintf(stderr, "\nstop audio play");
+	/* do the scsi cmd */
 
 	scgp->cmdname = "stop audio play";
 
-  return scg_cmd(scgp) >= 0 ? 0 : -1;
+	return scg_cmd(scgp) >= 0 ? 0 : -1;
 }
 
-int Play_atSCSI ( scgp, from_sector, sectors)
-	SCSI *scgp;
-	unsigned int from_sector;
-	unsigned int sectors;
+int Play_atSCSI ( SCSI *scgp, unsigned int from_sector, unsigned int sectors)
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
@@ -1410,17 +1336,13 @@ int Play_atSCSI ( scgp, from_sector, sectors)
 
 static caddr_t scsibuffer;	/* page aligned scsi transfer buffer */
 
-void init_scsibuf __PR((SCSI *, unsigned));
-
-void init_scsibuf(scgp, amt)
-	SCSI *scgp;
-	unsigned amt;
+void init_scsibuf(SCSI *scgp, unsigned amt)
 {
 	if (scsibuffer != NULL) {
 		fprintf(stderr, "the SCSI transfer buffer has already been allocated!\n");
 		exit(3);
 	}
-	scsibuffer = scg_getbuf(scgp, amt);
+	scsibuffer = (char*)scg_getbuf(scgp, amt);
 	if (scsibuffer == NULL) {
 		fprintf(stderr, "could not get SCSI transfer buffer!\n");
 		exit(3);
