@@ -62,7 +62,7 @@ extern	int	debug;
 extern	int	lverbose;
 extern	int	xdebug;
 
-LOCAL	int	curspeed = 1;
+LOCAL	int	curspeed = 177;
 
 LOCAL	int	mmc_load		__PR((SCSI *scgp));
 LOCAL	int	mmc_unload		__PR((SCSI *scgp));
@@ -1219,7 +1219,7 @@ LOCAL int speed_select_mmc(SCSI *scgp, int *speedp, int dummy)
 	int	val;
 
 	if (speedp)
-		curspeed = *speedp;
+		curspeed = *speedp * 177;
 	deflt_writemodes_mmc(scgp);
 
 	fillbytes((caddr_t)mode, sizeof(mode), '\0');
@@ -1261,13 +1261,13 @@ LOCAL int speed_select_mmc(SCSI *scgp, int *speedp, int dummy)
 	 * But the standard is rounding the wrong way.
 	 * Furtunately rounding down is guaranteed.
 	 */
-	if (scsi_set_speed(scgp, -1, curspeed*177) < 0)
+	if (scsi_set_speed(scgp, -1, curspeed) < 0)
 		return (-1);
 
 	if (scsi_get_speed(scgp, 0, &val) >= 0) {
 		if (val > 0) {
-			curspeed = val / 176;
-			*speedp = curspeed;
+			curspeed = val;
+			*speedp = curspeed / 176;
 		}
 	}
 	return (0);
@@ -1275,18 +1275,57 @@ LOCAL int speed_select_mmc(SCSI *scgp, int *speedp, int dummy)
 
 LOCAL int speed_select_mdvd(SCSI *scgp, int *speedp, int dummy)
 {
-  int retcode;
-  /* For the moment we just divide the CD speed by 7*/
+	Uchar	mode[0x100];
+	int	len;
+	struct	cd_mode_page_05 *mp;
+	int	val;
 
-  if(speedp!=NULL)
-     (*speedp)=(*speedp)*8;
-  
-  retcode=speed_select_mmc(scgp,speedp,dummy);
+	if (speedp)
+		curspeed = *speedp * 1350;
+	deflt_writemodes_mmc(scgp);
 
-  if(speedp!=NULL)
-     (*speedp)=(*speedp)/7;
-   return retcode;
- 
+	fillbytes((caddr_t)mode, sizeof(mode), '\0');
+
+	if (!get_mode_params(scgp, 0x05, "CD write parameter",
+			mode, (Uchar *)0, (Uchar *)0, (Uchar *)0, &len))
+		return (-1);
+	if (len == 0)
+		return (-1);
+
+	mp = (struct cd_mode_page_05 *)
+		(mode + sizeof(struct scsi_mode_header) +
+		((struct scsi_mode_header *)mode)->blockdesc_len);
+#ifdef	DEBUG
+	scg_prbytes("CD write parameter:", (Uchar *)mode, len);
+#endif
+
+
+	mp->test_write = dummy != 0;
+
+#ifdef	DEBUG
+	scg_prbytes("CD write parameter:", (Uchar *)mode, len);
+#endif
+	if (!set_mode_params(scgp, "CD write parameter", mode, len, 0, -1))
+		return (-1);
+
+	if (speedp == 0)
+		return (0);
+	/*
+	 * Neither set nor get speed.
+	 */
+
+	if (scsi_set_speed(scgp, -1, curspeed) < 0)
+		return (-1);
+
+	if (scsi_set_streaming(scgp, curspeed, curspeed) < 0)
+		return (-1);
+
+	if (scsi_get_speed(scgp, 0, &val) >= 0) {
+		if (val > 0) {
+			*speedp = curspeed / 1349;
+		}
+	}
+	return (0);
 }
 
 LOCAL int next_wr_addr_mmc(SCSI *scgp, int track, track_t *trackp, long *ap)
@@ -1757,8 +1796,8 @@ LOCAL int fixate_mmc(SCSI *scgp, int onp, int dummy, int toctype, int tracks, tr
 	scgp->silent--;
 
 	if (ret >= 0) {
-		wait_unit_ready(scgp, 420/curspeed);	/* XXX Wait for ATAPI */
-		waitfix_mmc(scgp, 420/curspeed);	/* XXX Wait for ATAPI */
+		wait_unit_ready(scgp, 420*177/curspeed);	/* XXX Wait for ATAPI */
+		waitfix_mmc(scgp, 420*177/curspeed);	/* XXX Wait for ATAPI */
 		return (ret);
 	}
 
@@ -1789,7 +1828,7 @@ LOCAL int fixate_mmc(SCSI *scgp, int onp, int dummy, int toctype, int tracks, tr
 	}
 
 	wait_unit_ready(scgp, 420);	/* XXX Wait for ATAPI */
-	waitfix_mmc(scgp, 420/curspeed);/* XXX Wait for ATAPI */
+	waitfix_mmc(scgp, 420*177/curspeed);/* XXX Wait for ATAPI */
 
 	if (!dummy &&
 		(ret >= 0 || (key == SC_UNIT_ATTENTION && code == 0x2E))) {
@@ -1801,14 +1840,14 @@ LOCAL int fixate_mmc(SCSI *scgp, int onp, int dummy, int toctype, int tracks, tr
 		 */
 		gettimeofday(&stoptime, (struct timezone *)0);
 		timevaldiff(&starttime, &stoptime);
-		if (stoptime.tv_sec < (220 / curspeed)) {
+		if (stoptime.tv_sec < (220*177 / curspeed)) {
 			unsigned secs;
 
 			if (lverbose) {
 				printf("Actual fixating time: %ld seconds\n",
 							(long)stoptime.tv_sec);
 			}
-			secs = (280 / curspeed) - stoptime.tv_sec;
+			secs = (280*177 / curspeed) - stoptime.tv_sec;
 			if (lverbose) {
 				printf("ATAPI early return: sleeping %d seconds.\n",
 								secs);
