@@ -80,7 +80,6 @@ extern "C" {
 
 #if	defined(HAVE_LARGEFILES)
 #	define	_fcons		_fcons64
-#	define	fdup		fdup64
 #	define	fileluopen	fileluopen64
 #	define	fileopen	fileopen64
 #	define	filepos		filepos64
@@ -93,22 +92,7 @@ extern "C" {
 #ifdef	EOF	/* stdio.h has been included */
 extern	int	_cvmod __PR((const char *, int *, int *));
 extern	FILE	*_fcons __PR((FILE *, int, int));
-extern	FILE	*fdup __PR((FILE *));
 extern	int	fdown __PR((FILE *));
-extern	int	fexecl __PR((const char *, FILE *, FILE *, FILE *,
-							const char *, ...));
-extern	int	fexecle __PR((const char *, FILE *, FILE *, FILE *,
-							const char *, ...));
-		/* 6th arg not const, fexecv forces av[ac] = NULL */
-extern	int	fexecv __PR((const char *, FILE *, FILE *, FILE *, int,
-							char **));
-extern	int	s_fexecve __PR((const char *, FILE *, FILE *, FILE *,
-					char * const *, char * const *));
-extern	int	fspawnv __PR((FILE *, FILE *, FILE *, int, char * const *));
-extern	int	fspawnl __PR((FILE *, FILE *, FILE *,
-					const char *, const char *, ...));
-extern	int	fspawnv_nowait __PR((FILE *, FILE *, FILE *,
-					const char *, int, char *const*));
 extern	int	fgetline __PR((FILE *, char *, int));
 extern	int	fgetstr __PR((FILE *, char *, int));
 extern	void	file_raise __PR((FILE *, int));
@@ -119,14 +103,12 @@ extern	FILE	*fileopen __PR((const char *, const char *));
 extern	off_t	filepos __PR((FILE *));
 #endif
 extern	int	fileread __PR((FILE *, void *, int));
-extern	int	ffileread __PR((FILE *, void *, int));
 extern	FILE	*filereopen __PR((const char *, const char *, FILE *));
 #ifdef	FOUND_OFF_T
 extern	int	fileseek __PR((FILE *, off_t));
 extern	off_t	filesize __PR((FILE *));
 #endif
 extern	int	filewrite __PR((FILE *, void *, int));
-extern	int	ffilewrite __PR((FILE *, void *, int));
 extern	int	flush __PR((void));
 extern	int	fpipe __PR((FILE **));
 /*extern	int	fprintf __PR((FILE *, const char *, ...)) __printflike__(2, 3);*/
@@ -213,7 +195,6 @@ extern	char	*get_progname __PR((void));
 
 extern	void	setfp __PR((void * const *));
 extern	int	wait_chld __PR((int));		/* for fspawnv_nowait() */
-extern	int	geterrno __PR((void));
 extern	void	raisecond __PR((const char *, long));
 #ifdef	FOUND_SIZE_T
 /*
@@ -237,6 +218,19 @@ extern	int	format __PR((void (*)(char, long), long, const char *, void *));
 extern	int	ftoes __PR((char *, double, int, int));
 extern	int	ftofs __PR((char *, double, int, int));
 
+#ifdef  EOF     /* stdio.h has been included */
+/*PRINTFLIKE2*/
+extern	int	js_fprintf	__PR((FILE *, const char *, ...)) __printflike__(2, 3);
+/*PRINTFLIKE1*/
+extern	int	js_printf	__PR((const char *, ...)) __printflike__(1, 2);
+#ifdef  FOUND_SIZE_T
+/*PRINTFLIKE3*/
+extern	int	js_snprintf	__PR((char *, size_t, const char *, ...)) __printflike__(3, 4);
+#endif
+/*PRINTFLIKE2*/
+extern	int	js_sprintf	__PR((char *, const char *, ...)) __printflike__(2, 3);
+#endif  /* EOF */
+
 extern	void	swabbytes __PR((void *, int));
 extern	char	*getav0 __PR((void));
 extern	char	**getavp __PR((void));
@@ -250,7 +244,6 @@ extern	int	cmpbytes __PR((const void *, const void *, int));
  * To allow this, we need to figure out how to do autoconfiguration for off64_t
  */
 extern	FILE	*_fcons64	__PR((FILE *, int, int));
-extern	FILE	*fdup64		__PR((FILE *));
 extern	FILE	*fileluopen64	__PR((int, const char *));
 extern	FILE	*fileopen64	__PR((const char *, const char *));
 #ifdef	FOUND_OFF_T
