@@ -47,7 +47,7 @@ static	char sccsid[] =
 
 #ifndef	lint
 static char *moduleid = 
-	"@(#)$Id: apprentice.c,v 1.1.1.1 2003/12/11 23:23:10 bero Exp $";
+	"@(#)$Id: apprentice.c,v 1.2 2005/02/05 01:01:57 bero Exp $";
 #endif	/* lint */
 
 int	__f_nmagic = 0;		/* number of valid magic[]s 		*/
@@ -74,8 +74,7 @@ static int apprentice_1	__P((char *, int));
  * based on the original apprentice()
  */
 int
-init_magic(fn)
-char *fn;			/* list of magic files */
+init_magic(char *fn)
 {
         maxmagic = MAXMAGIS;
 	__f_magic = (struct magic *) calloc(sizeof(struct magic), maxmagic);
@@ -86,9 +85,7 @@ char *fn;			/* list of magic files */
 }
 
 static int
-apprentice_1(fn, check)
-char *fn;			/* name of magic file */
-int check;			/* non-zero? checking-only run. */
+apprentice_1(char *fn, int check)
 {
 	static const char hdr[] =
 		"cont\toffset\ttype\topcode\tmask\tvalue\tdesc";
@@ -125,9 +122,7 @@ int check;			/* non-zero? checking-only run. */
  * XXX is uint32 really a good idea XXX JS
  */
 UInt32_t
-signextend(m, v)
-struct magic *m;
-UInt32_t v;
+signextend(struct magic *m, UInt32_t v)
 {
 	if (!(m->flag & UNSIGNED))
 		switch(m->type) {
@@ -164,9 +159,7 @@ UInt32_t v;
  * parse one line from magic file, put into magic[index++] if valid
  */
 static int
-parse(l, ndx, check)
-char *l;
-int *ndx, check;
+parse(char *l, int *ndx, int check)
 {
 	int i = 0, nd = *ndx;
 	struct magic *m;
@@ -388,9 +381,7 @@ GetDesc:
  * just after the number read.  Return 0 for success, non-zero for failure.
  */
 static int
-getvalue(m, p)
-struct magic *m;
-char **p;
+getvalue(struct magic *m, char **p)
 {
 	int slen;
 
@@ -412,10 +403,7 @@ char **p;
  * Return updated scan pointer as function result.
  */
 static char *
-getstr(s, p, plen, slen)
-register char	*s;
-register char	*p;
-int	plen, *slen;
+getstr(char *s, char *p, int plen, int *slen)
 {
 	char	*origs = s, *origp = p;
 	char	*pmax = p + plen - 1;
@@ -515,8 +503,7 @@ out:
 
 /* Single hex char to int; -1 if not a hex char. */
 static int
-hextoint(c)
-int c;
+hextoint(int c)
 {
 	if (!isascii((unsigned char) c))	return -1;
 	if (isdigit((unsigned char) c))		return c - '0';
@@ -530,10 +517,7 @@ int c;
  * Print a string containing C character escapes.
  */
 void
-showstr(fp, s, len)
-FILE *fp;
-const char *s;
-int len;
+showstr(FILE *fp, const char *s, int len)
 {
 	register char	c;
 
@@ -589,8 +573,7 @@ int len;
  * eatsize(): Eat the size spec from a number [eg. 10UL]
  */
 static void
-eatsize(p)
-char **p;
+eatsize(char **p)
 {
 	char *l = *p;
 
