@@ -47,7 +47,7 @@ static	char sccsid[] =
 
 #ifndef	lint
 static char *moduleid = 
-	"@(#)$Id: softmagic.c,v 1.1.1.1 2003/12/11 23:23:10 bero Exp $";
+	"@(#)$Id: softmagic.c,v 1.2 2005/02/05 01:01:57 bero Exp $";
 #endif	/* lint */
 
 #ifdef DEBUG
@@ -74,9 +74,7 @@ static int mconvert	__P((union VALUETYPE *, struct magic *));
  */
 /*ARGSUSED1*/		/* nbytes passed for regularity, maybe need later */
 char *
-softmagic(buf, nbytes)
-unsigned char *buf;
-int nbytes;
+softmagic(unsigned char *buf, int nbytes)
 {
 	return (match(buf, nbytes));
 }
@@ -109,9 +107,7 @@ int nbytes;
  *	so that higher-level continuations are processed.
  */
 static char *
-match(s, nbytes)
-unsigned char	*s;
-int nbytes;
+match(unsigned char *s, int nbytes)
 {
 	int magindex = 0;
 	union VALUETYPE p;
@@ -140,9 +136,7 @@ int nbytes;
  * Convert the byte order of the data we are looking at
  */
 static int
-mconvert(p, m)
-union VALUETYPE *p;
-struct magic *m;
+mconvert(union VALUETYPE *p, struct magic *m)
 {
 	switch (m->type) {
 	case BYTE:
@@ -183,10 +177,7 @@ struct magic *m;
 
 #ifdef	__used__
 static void
-mdebug(offset, str, len)
-Int32_t offset;
-char *str;
-int len;
+mdebug(Int32_t offset, char *str, int len)
 {
 	(void) fprintf(stderr, "mget @%d: ", offset);
 	showstr(stderr, (char *) str, len);
@@ -196,11 +187,7 @@ int len;
 #endif
 
 static int
-mget(p, s, m, nbytes)
-union VALUETYPE* p;
-unsigned char	*s;
-struct magic *m;
-int nbytes;
+mget(union VALUETYPE *p, unsigned char *s, struct magic *m, int nbytes)
 {
 	Int32_t offset = m->offset;
 
@@ -246,9 +233,7 @@ int nbytes;
 }
 
 static int
-magcheck(p, m)
-union VALUETYPE* p;
-struct magic *m;
+magcheck(union VALUETYPE *p, struct magic *m)
 {
 	register UInt32_t l = m->value.l;
 	register UInt32_t v;
