@@ -164,9 +164,7 @@ scg_remote()
  * in applications.
  */
 LOCAL char *
-scgo_rversion(scgp, what)
-	SCSI	*scgp;
-	int	what;
+scgo_rversion(SCSI *scgp, int what)
 {
 	int	f;
 
@@ -210,9 +208,7 @@ scgo_rversion(scgp, what)
 }
 
 LOCAL int
-scgo_ropen(scgp, device)
-	SCSI	*scgp;
-	char	*device;
+scgo_ropen(SCSI *scgp, char *device)
 {
 		 int	busno	= scg_scsibus(scgp);
 		 int	tgt	= scg_target(scgp);
@@ -282,8 +278,7 @@ scgo_ropen(scgp, device)
 }
 
 LOCAL int
-scgo_rclose(scgp)
-	SCSI	*scgp;
+scgo_rclose(SCSI *scgp)
 {
 	register int	f;
 		 int	ret;
@@ -315,9 +310,7 @@ scgo_rclose(scgp)
 }
 
 LOCAL long
-scgo_rmaxdma(scgp, amt)
-	SCSI	*scgp;
-	long	amt;
+scgo_rmaxdma(SCSI *scgp, long amt)
 {
 	if (scgp->local == NULL)
 		return (-1L);
@@ -326,9 +319,7 @@ scgo_rmaxdma(scgp, amt)
 }
 
 LOCAL void *
-scgo_rgetbuf(scgp, amt)
-	SCSI	*scgp;
-	long	amt;
+scgo_rgetbuf(SCSI *scgp, long amt)
 {
 	int	ret;
 
@@ -352,8 +343,7 @@ scgo_rgetbuf(scgp, amt)
 }
 
 LOCAL void
-scgo_rfreebuf(scgp)
-	SCSI	*scgp;
+scgo_rfreebuf(SCSI *scgp)
 {
 	int	f;
 
@@ -371,9 +361,7 @@ scgo_rfreebuf(scgp)
 }
 
 LOCAL BOOL
-scgo_rhavebus(scgp, busno)
-	SCSI	*scgp;
-	int	busno;
+scgo_rhavebus(SCSI *scgp, int busno)
 {
 	if (scgp->local == NULL || busno < 0 || busno >= MAX_SCG)
 		return (FALSE);
@@ -382,11 +370,7 @@ scgo_rhavebus(scgp, busno)
 }
 
 LOCAL int
-scgo_rfileno(scgp, busno, tgt, tlun)
-	SCSI	*scgp;
-	int	busno;
-	int	tgt;
-	int	tlun;
+scgo_rfileno(SCSI *scgp, int busno, int tgt, int tlun)
 {
 	int	f;
 
@@ -403,8 +387,7 @@ scgo_rfileno(scgp, busno, tgt, tlun)
 }
 
 LOCAL int
-scgo_rinitiator_id(scgp)
-	SCSI	*scgp;
+scgo_rinitiator_id(SCSI *scgp)
 {
 	if (scgp->local == NULL)
 		return (-1);
@@ -413,8 +396,7 @@ scgo_rinitiator_id(scgp)
 }
 
 LOCAL int 
-scgo_risatapi(scgp)
-	SCSI	*scgp;
+scgo_risatapi(SCSI *scgp)
 {
 	if (scgp->local == NULL)
 		return (-1);
@@ -423,9 +405,7 @@ scgo_risatapi(scgp)
 }
 
 LOCAL int
-scgo_rreset(scgp, what)
-	SCSI	*scgp;
-	int	what;
+scgo_rreset(SCSI *scgp, int what)
 {
 	if (scgp->local == NULL)
 		return (-1);
@@ -434,8 +414,7 @@ scgo_rreset(scgp, what)
 }
 
 LOCAL int
-scgo_rsend(scgp)
-	SCSI		*scgp;
+scgo_rsend(SCSI *scgp)
 {
 	struct scg_cmd	*sp = scgp->scmd;
 	int		ret;
@@ -454,16 +433,13 @@ scgo_rsend(scgp)
 
 /*--------------------------------------------------------------------------*/
 LOCAL void
-rscsiabrt(sig)
-	int	sig;
+rscsiabrt(int sig)
 {
 	rscsiaborted((SCSI *)0, -1);
 }
 
 LOCAL int
-rscsigetconn(scgp, host)
-	SCSI	*scgp;
-	char	*host;
+rscsigetconn(SCSI *scgp, char *host)
 {
 	static	struct servent	*sp = 0;
 	static	struct passwd	*pw = 0;
@@ -506,10 +482,7 @@ rscsigetconn(scgp, host)
 }
 
 LOCAL char *
-rscsiversion(scgp, fd, what)
-	SCSI	*scgp;
-	int	fd;
-	int	what;
+rscsiversion(SCSI *scgp, int fd, int what)
 {
 	char	cbuf[CMD_SIZE];
 	char	*p;
@@ -517,7 +490,7 @@ rscsiversion(scgp, fd, what)
 
 	snprintf(cbuf, sizeof(cbuf), "V%d\n", what);
 	ret = rscsicmd(scgp, fd, "version", cbuf);
-	p = malloc(ret);
+	p = (char*)malloc(ret);
 	if (p == NULL)
 		return (p);
 	rscsireadbuf(scgp, fd, p, ret);
@@ -525,10 +498,7 @@ rscsiversion(scgp, fd, what)
 }
 
 LOCAL int
-rscsiopen(scgp, fd, fname)
-	SCSI	*scgp;
-	int	fd;
-	char	*fname;
+rscsiopen(SCSI *scgp, int fd, char *fname)
 {
 	char	cbuf[CMD_SIZE];
 	int	ret;
@@ -552,18 +522,13 @@ rscsiopen(scgp, fd, fname)
 }
 
 LOCAL int
-rscsiclose(scgp, fd)
-	SCSI	*scgp;
-	int	fd;
+rscsiclose(SCSI *scgp, int fd)
 {
 	return (rscsicmd(scgp, fd, "close", "C\n"));
 }
 
 LOCAL int
-rscsimaxdma(scgp, fd, amt)
-	SCSI	*scgp;
-	int	fd;
-	long	amt;
+rscsimaxdma(SCSI *scgp, int fd, long amt)
 {
 	char	cbuf[CMD_SIZE];
 
@@ -572,10 +537,7 @@ rscsimaxdma(scgp, fd, amt)
 }
 
 LOCAL int
-rscsigetbuf(scgp, fd, amt)
-	SCSI	*scgp;
-	int	fd;
-	long	amt;
+rscsigetbuf(SCSI *scgp, int fd, long amt)
 {
 	char	cbuf[CMD_SIZE];
 	int	size;
@@ -616,18 +578,13 @@ rscsigetbuf(scgp, fd, amt)
 }
 
 LOCAL int
-rscsifreebuf(scgp, fd)
-	SCSI	*scgp;
-	int	fd;
+rscsifreebuf(SCSI *scgp, int fd)
 {
 	return (rscsicmd(scgp, fd, "freebuf", "F\n"));
 }
 
 LOCAL int
-rscsihavebus(scgp, fd, busno)
-	SCSI	*scgp;
-	int	fd;
-	int	busno;
+rscsihavebus(SCSI *scgp, int fd, int busno)
 {
 	char	cbuf[2*CMD_SIZE];
 
@@ -638,12 +595,7 @@ rscsihavebus(scgp, fd, busno)
 }
 
 LOCAL int
-rscsifileno(scgp, fd, busno, tgt, tlun)
-	SCSI	*scgp;
-	int	fd;
-	int	busno;
-	int	tgt;
-	int	tlun;
+rscsifileno(SCSI *scgp, int fd, int busno, int tgt, int tlun)
 {
 	char	cbuf[3*CMD_SIZE];
 
@@ -656,26 +608,19 @@ rscsifileno(scgp, fd, busno, tgt, tlun)
 }
 
 LOCAL int
-rscsiinitiator_id(scgp, fd)
-	SCSI	*scgp;
-	int	fd;
+rscsiinitiator_id(SCSI *scgp, int fd)
 {
 	return (rscsicmd(scgp, fd, "initiator id", "I\n"));
 }
 
 LOCAL int
-rscsiisatapi(scgp, fd)
-	SCSI	*scgp;
-	int	fd;
+rscsiisatapi(SCSI *scgp, int fd)
 {
 	return (rscsicmd(scgp, fd, "isatapi", "A\n"));
 }
 
 LOCAL int
-rscsireset(scgp, fd, what)
-	SCSI	*scgp;
-	int	fd;
-	int	what;
+rscsireset(SCSI *scgp, int fd, int what)
 {
 	char	cbuf[CMD_SIZE];
 
@@ -684,10 +629,7 @@ rscsireset(scgp, fd, what)
 }
 
 LOCAL int
-rscsiscmd(scgp, fd, sp)
-	SCSI	*scgp;
-	int	fd;
-	struct scg_cmd  *sp;
+rscsiscmd(SCSI *scgp, int fd, struct scg_cmd *sp)
 {
 	char	cbuf[1600];
 	int	ret;
@@ -744,8 +686,7 @@ rscsiscmd(scgp, fd, sp)
 }
 
 LOCAL int
-rscsifillrbuf(scgp)
-	SCSI	*scgp;
+rscsifillrbuf(SCSI *scgp)
 {
 	scglocal(scgp)->readbptr = scglocal(scgp)->readbuf;
 
@@ -755,9 +696,7 @@ rscsifillrbuf(scgp)
 }
 
 LOCAL int
-rscsirchar(scgp, cp)
-	SCSI	*scgp;
-	char	*cp;
+rscsirchar(SCSI *scgp, char *cp)
 {
 	if (--(scglocal(scgp)->readbcnt) < 0) {
 		if (rscsifillrbuf(scgp) <= 0)
@@ -769,11 +708,7 @@ rscsirchar(scgp, cp)
 }
 
 LOCAL int
-rscsireadbuf(scgp, fd, buf, count)
-	SCSI	*scgp;
-	int	fd;
-	char	*buf;
-	int	count;
+rscsireadbuf(SCSI *scgp, int fd, char *buf, int count)
 {
 	register int	n = count;
 	register int	amt = 0;
@@ -798,10 +733,7 @@ rscsireadbuf(scgp, fd, buf, count)
 }
 
 LOCAL void
-rscsivoidarg(scgp, fd, n)
-	SCSI	*scgp;
-	int	fd;
-	register int	n;
+rscsivoidarg(SCSI *scgp, int fd, int n)
 {
 	register int	i;
 	register int	amt;
@@ -816,22 +748,14 @@ rscsivoidarg(scgp, fd, n)
 }
 
 LOCAL int
-rscsicmd(scgp, fd, name, cbuf)
-	SCSI	*scgp;
-	int	fd;
-	char	*name;
-	char	*cbuf;
+rscsicmd(SCSI *scgp, int fd, char *name, char *cbuf)
 {
 	rscsisendcmd(scgp, fd, name, cbuf);
 	return (rscsigetstatus(scgp, fd, name));
 }
 
 LOCAL void
-rscsisendcmd(scgp, fd, name, cbuf)
-	SCSI	*scgp;
-	int	fd;
-	char	*name;
-	char	*cbuf;
+rscsisendcmd(SCSI *scgp, int fd, char *name, char *cbuf)
 {
 	int	buflen = strlen(cbuf);
 
@@ -841,11 +765,7 @@ rscsisendcmd(scgp, fd, name, cbuf)
 }
 
 LOCAL int
-rscsigetline(scgp, fd, line, count)
-	SCSI	*scgp;
-	int	fd;
-	char	*line;
-	int	count;
+rscsigetline(SCSI *scgp, int fd, char *line, int count)
 {
 	register char	*cp;
 
@@ -862,9 +782,7 @@ rscsigetline(scgp, fd, line, count)
 }
 
 LOCAL int
-rscsireadnum(scgp, fd)
-	SCSI	*scgp;
-	int	fd;
+rscsireadnum(SCSI *scgp, int fd)
 {
 	char	cbuf[CMD_SIZE];
 
@@ -873,10 +791,7 @@ rscsireadnum(scgp, fd)
 }
 
 LOCAL int
-rscsigetstatus(scgp, fd, name)
-	SCSI	*scgp;
-	int	fd;
-	char	*name;
+rscsigetstatus(SCSI *scgp, int fd, char *name)
 {
 	char	cbuf[CMD_SIZE];
 	char	code;
@@ -922,9 +837,7 @@ rscsigetstatus(scgp, fd, name)
 }
 
 LOCAL int
-rscsiaborted(scgp, fd)
-	SCSI	*scgp;
-	int	fd;
+rscsiaborted(SCSI *scgp, int fd)
 {
 	if ((scgp && scgp->debug > 0) || debug)
 		errmsgno(EX_BAD, "Lost connection to remote host ??\n");
