@@ -150,9 +150,7 @@ LOCAL	int	scan_internal __PR((SCSI * scgp, int *fatal));
  * in applications.
  */
 LOCAL char *
-scgo_aversion(scgp, what)
-	SCSI	*scgp;
-	int	what;
+scgo_aversion(SCSI *scgp, int what)
 {
 	if (scgp != (SCSI *)0) {
 		switch (what) {
@@ -173,9 +171,7 @@ scgo_aversion(scgp, what)
 }
 
 LOCAL int
-scgo_aopen(scgp, device)
-	SCSI	*scgp;
-	char	*device;
+scgo_aopen(SCSI *scgp, char *device)
 {
 	int	bus = scg_scsibus(scgp);
 	int	target = scg_target(scgp);
@@ -266,9 +262,7 @@ openbydev:
 }
 
 LOCAL int
-scan_internal(scgp, nopen)
-	SCSI	*scgp;
-	int	*nopen;
+scan_internal(SCSI *scgp, int *nopen)
 {
 	int	i,
 		f;
@@ -393,8 +387,7 @@ scan_internal(scgp, nopen)
 }
 
 LOCAL int
-scgo_aclose(scgp)
-	SCSI	*scgp;
+scgo_aclose(SCSI *scgp)
 {
 	register int	f;
 	register int	h;
@@ -426,11 +419,7 @@ scgo_aclose(scgp)
 }
 
 LOCAL int
-scgo_aget_first_free_shillybus(scgp, subsystem, host, bus)
-	SCSI	*scgp;
-	int	subsystem;
-	int	host;
-	int	bus;
+scgo_aget_first_free_shillybus(SCSI *scgp, int subsystem, int host, int bus)
 {
 	int	first_free_schilly_bus;
 
@@ -455,11 +444,7 @@ scgo_aget_first_free_shillybus(scgp, subsystem, host, bus)
 }
 
 LOCAL int
-scgo_amerge(path, readedlink, buffer, buflen)
-	char	*path;
-	char	*readedlink;
-	char	*buffer;
-	int	buflen;
+scgo_amerge(char *path, char *readedlink, char *buffer, int buflen)
 {
 	char	*aa;
 
@@ -597,13 +582,7 @@ scgo_amerge(path, readedlink, buffer, buflen)
  *
  */
 LOCAL BOOL
-sg_amapdev(scgp, f, device, schillybus, target, lun)
-	SCSI	*scgp;
-	int	f;
-	char	*device;
-	int	*schillybus;
-	int	*target;
-	int	*lun;
+sg_amapdev(SCSI *scgp, int f, char *device, int *schillybus, int *targetno, int *lunno)
 {
 	struct host {
 		char	host[4];
@@ -840,8 +819,8 @@ sg_amapdev(scgp, f, device, schillybus, target, lun)
 		hostlocal(scgp, first_free_schilly_bus) = h;
 		buslocal(scgp, first_free_schilly_bus) = b;
 		*schillybus = first_free_schilly_bus;
-		*target = t;
-		*lun = l;
+		*targetno = t;
+		*lunno = l;
 
 		if (scgp->debug > 1) {
 			fprintf((FILE *) scgp->errfile,
@@ -854,14 +833,7 @@ sg_amapdev(scgp, f, device, schillybus, target, lun)
 }
 
 LOCAL BOOL
-sg_amapdev_scsi(scgp, f, busp, tgtp, lunp, chanp, inop)
-	SCSI	*scgp;
-	int	f;
-	int	*busp;
-	int	*tgtp;
-	int	*lunp;
-	int	*chanp;
-	int	*inop;
+sg_amapdev_scsi(SCSI *scgp, int f, int *busp, int *tgtp, int *lunp, int *chanp, int *inop)
 {
 	struct sg_id {
 		long	l1;	/* target | lun << 8 | channel << 16 | low_ino << 24 */
@@ -903,9 +875,7 @@ sg_amapdev_scsi(scgp, f, busp, tgtp, lunp, chanp, inop)
 }
 
 LOCAL long
-scgo_amaxdma(scgp, amt)
-	SCSI	*scgp;
-	long	amt;
+scgo_amaxdma(SCSI *scgp, long amt)
 {
 	/*
 	 * EINVAL (hart) ENOMEM (weich) bei mehr ...
@@ -915,9 +885,7 @@ scgo_amaxdma(scgp, amt)
 }
 
 LOCAL BOOL
-scgo_ahavebus(scgp, busno)
-	SCSI	*scgp;
-	int	busno;
+scgo_ahavebus(SCSI *scgp, int busno)
 {
 	register int	t;
 	register int	l;
@@ -937,11 +905,7 @@ scgo_ahavebus(scgp, busno)
 }
 
 LOCAL int
-scgo_afileno(scgp, busno, tgt, tlun)
-	SCSI	*scgp;
-	int	busno;
-	int	tgt;
-	int	tlun;
+scgo_afileno(SCSI *scgp, int busno, int tgt, int tlun)
 {
 	if (busno < 0 || busno >= MAX_SCHILLY_HOSTS ||
 		tgt < 0 || tgt >= MAX_TGT ||
@@ -955,16 +919,14 @@ scgo_afileno(scgp, busno, tgt, tlun)
 }
 
 LOCAL int
-scgo_ainitiator_id(scgp)
-	SCSI	*scgp;
+scgo_ainitiator_id(SCSI *scgp)
 {
 	printf(scgp->errstr, "NOT IMPELEMENTED: scgo_initiator_id");
 	return (-1);
 }
 
 LOCAL int
-scgo_aisatapi(scgp)
-	SCSI	*scgp;
+scgo_aisatapi(SCSI *scgp)
 {
 	int schillybus = scgp->addr.scsibus;
 	int typ = typlocal(scgp, schillybus);
@@ -977,9 +939,7 @@ scgo_aisatapi(scgp)
 }
 
 LOCAL int
-scgo_areset(scgp, what)
-	SCSI	*scgp;
-	int	what;
+scgo_areset(SCSI *scgp, int what)
 {
 	if (what == SCG_RESET_NOP)
 		return (0);
@@ -991,8 +951,7 @@ scgo_areset(scgp, what)
 }
 
 LOCAL int
-scgo_asend(scgp)
-	SCSI	*scgp;
+scgo_asend(SCSI *scgp)
 {
 	struct scg_cmd	*sp = scgp->scmd;
 	int		ret,
@@ -1040,7 +999,7 @@ scgo_asend(scgp)
 	}
 
 	sg_cgc.buflen = sp->size;
-	sg_cgc.buffer = sp->addr;
+	sg_cgc.buffer = (unsigned char *)sp->addr;
 
 	if (sp->sense_len > sizeof (sense_cgc))
 		sense_cgc.add_sense_len = sizeof (sense_cgc) - 8;
