@@ -58,7 +58,14 @@ static	char __sccsid[] =
  * 02111-1307  USA
  */
 
+#include <stdint.h>
 #include <linux/version.h>
+#undef sense
+#include <linux/cdrom.h>
+
+#if defined(CDROM_PACKET_SIZE) && defined(CDROM_SEND_PACKET)
+#define USE_ATA
+#endif
 
 #ifndef LINUX_VERSION_CODE	/* Very old kernel? */
 #	define LINUX_VERSION_CODE 0
@@ -88,7 +95,7 @@ static	char __sccsid[] =
  *	Choose your name instead of "schily" and make clear that the version
  *	string is related to a modified source.
  */
-LOCAL	char	_scg_trans_version[] = "scsi-linux-sg.c-1.69";	/* The version for this transport*/
+LOCAL	char	_scg_trans_version[] = "dvdrecord-scsi-linux-sg.c-1.69";	/* The version for this transport*/
 
 #ifndef	SCSI_IOCTL_GET_BUS_NUMBER
 #define SCSI_IOCTL_GET_BUS_NUMBER 0x5386
@@ -128,12 +135,24 @@ LOCAL	char	_scg_trans_version[] = "scsi-linux-sg.c-1.69";	/* The version for thi
 
 /*
  * XXX Should add extra space in buscookies and scgfiles for a "PP bus"
- * XXX and for two "ATAPI busses".
+ * XXX and for two or more "ATAPI busses".
  */
-#define	MAX_SCG		16	/* Max # of SCSI controllers */
+#define	MAX_SCG		256	/* Max # of SCSI controllers */
 #define	MAX_TGT		16
 #define	MAX_LUN		8
 
+#ifdef USE_ATA
+/*
+ * # of virtual buses
+ */
+#define MAX_SCHILLY_HOSTS	MAX_SCG
+typedef struct {
+	Uchar	typ:4;
+	Uchar	bus:4;
+	Uchar	host:8;
+} ata_buscookies;
+#endif
+
 struct scg_local {
 	int	scgfile;		/* Used for SG_GET_BUFSIZE ioctl()*/
 	short	scgfiles[MAX_SCG][MAX_TGT][MAX_LUN];
@@ -142,12 +161,21 @@ struct scg_local {
 	int	pack_id;		/* Should be a random number	*/
 	int	drvers;
 	int	isold;
+	short	flags;
 	long	xbufsize;
 	char	*xbuf;
 	char	*SCSIbuf;
+#ifdef USE_ATA
+	ata_buscookies bc[MAX_SCHILLY_HOSTS];
+#endif
 };
 #define scglocal(p)	((struct scg_local *)((p)->local)) 
 
+/*
+ * Flag definitions
+ */
+#define LF_ATA	0x01			/* Using /dev/hd* ATA interface */
+
 #ifdef	SG_BIG_BUFF
 #define	MAX_DMA_LINUX	SG_BIG_BUFF	/* Defined in include/scsi/sg.h	*/
 #else
@@ -167,6 +195,9 @@ struct scg_local {
 #if	defined(USE_PG) && !defined(USE_PG_ONLY)
 #include "scsi-linux-pg.c"
 #endif
+#ifdef USE_ATA
+#include "scsi-linux-ata.c"
+#endif
 
 #ifdef	MISALIGN
 LOCAL	int	sg_getint	__PR((int *ip));
@@ -175,11 +206,12 @@ LOCAL	int	scgo_send	__PR((SCSI *scgp));
 #ifdef	SG_IO
 LOCAL	int	sg_rwsend	__PR((SCSI *scgp));
 #endif
-LOCAL	BOOL	sg_setup	__PR((SCSI *scgp, int f, int busno, int tgt, int tlun));
+LOCAL	void	sg_clearnblock	__PR((int f));
+LOCAL	BOOL	sg_setup	__PR((SCSI *scgp, int f, int busno, int tgt, int tlun, int ataidx));
 LOCAL	void	sg_initdev	__PR((SCSI *scgp, int f));
 LOCAL	int	sg_mapbus	__PR((SCSI *scgp, int busno, int ino));
 LOCAL	BOOL	sg_mapdev	__PR((SCSI *scgp, int f, int *busp, int *tgtp, int *lunp,
-							int *chanp, int *inop));
+							int *chanp, int *inop, int ataidx));
 #if defined(SG_SET_RESERVED_SIZE) && defined(SG_GET_RESERVED_SIZE)
 LOCAL	long	sg_raisedma	__PR((SCSI *scgp, long newmax));
 #endif
@@ -191,9 +223,7 @@ LOCAL	void	sg_settimeout	__PR((int f, int timeout));
  * in applications.
  */
 LOCAL char *
-scgo_version(scgp, what)
-	SCSI	*scgp;
-	int	what;
+scgo_version(SCSI *scgp, int what)
 {
 	if (scgp != (SCSI *)0) {
 #ifdef	USE_PG
@@ -225,7 +255,7 @@ scgo_version(scgp, what)
 
 				if (scglocal(scgp)->drvers >= 0) {
 					n = scglocal(scgp)->drvers;
-					js_snprintf(kv, sizeof(kv),
+					snprintf(kv, sizeof(kv),
                                         "%d.%d.%d",
                                         n/10000, (n%10000)/100, n%100);
 
@@ -238,9 +268,7 @@ scgo_version(scgp, what)
 }
 
 LOCAL int
-scgo_open(scgp, device)
-	SCSI	*scgp;
-	char	*device;
+scgo_open(SCSI *scgp, char *device)
 {
 		 int	busno	= scg_scsibus(scgp);
 		 int	tgt	= scg_target(scgp);
@@ -252,16 +280,30 @@ scgo_open(scgp, device)
 	register int	l;
 	register int	nopen = 0;
 	char		devname[64];
+	BOOL		use_ata = FALSE;
 
 	if (busno >= MAX_SCG || tgt >= MAX_TGT || tlun >= MAX_LUN) {
 		errno = EINVAL;
 		if (scgp->errstr)
-			js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+			snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 				"Illegal value for busno, target or lun '%d,%d,%d'",
 				busno, tgt, tlun);
 		return (-1);
 	}
 
+	if (device != NULL && *device != '\0') {
+#ifdef USE_ATA
+		if(strncmp(device, "ATAPI", 5) == 0) {
+			scgp->ops = &ata_ops;
+			return (SCGO_OPEN(scgp, device));
+		} else
+#endif
+		if(strcmp(device, "ATA") == 0) {
+			use_ata = TRUE;
+			device = NULL;
+		}
+	}
+
 	if (scgp->local == NULL) {
 		scgp->local = malloc(sizeof(struct scg_local));
 		if (scgp->local == NULL)
@@ -273,6 +315,7 @@ scgo_open(scgp, device)
 		scglocal(scgp)->pack_id = 5;
 		scglocal(scgp)->drvers = -1;
 		scglocal(scgp)->isold = -1;
+		scglocal(scgp)->flags = use_ata ? LF_ATA : 0;
 		scglocal(scgp)->xbufsize = 0L;
 		scglocal(scgp)->xbuf = NULL;
 
@@ -285,28 +328,65 @@ scgo_open(scgp, device)
 		}
 	}
 
+	if (use_ata)
+		goto scanopen;
+
 	if ((device != NULL && *device != '\0') || (busno == -2 && tgt == -2))
 		goto openbydev;
 
-	for (i=0; i < 32; i++) {
-		js_snprintf(devname, sizeof(devname), "/dev/sg%d", i);
-		f = open(devname, 2);
+scanopen:
+	if (use_ata) for(i=0; i<=25; i++) {
+		snprintf(devname, sizeof(devname), "/dev/hd%c", i+'a');
+		f = open(devname, O_RDWR|O_NONBLOCK);
+		if (f < 0) {
+			if (scgp->errstr)
+				snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+						"Cannot open /dev/hd*");
+			if (errno != ENOENT && errno != ENXIO && errno != ENODEV) {
+				if (scgp->errstr)
+					snprintf(scgp->errstr, SCSI_ERRSTR_SIZE, "Cannot open '%s'", devname);
+				return 0;
+			}
+		} else {
+			int iparm;
+			if (ioctl(f, SG_GET_TIMEOUT, &iparm) < 0) {
+				if (scgp->errstr)
+					snprintf(scgp->errstr, SCSI_ERRSTR_SIZE, "SCSI unsupported with '%s'", devname);
+				close(f);
+				continue;
+			}
+			sg_clearnblock(f);
+			if (sg_setup(scgp, f, busno, tgt, tlun, i))
+				return (++nopen);
+			if (busno < 0 && tgt < 0 && tlun < 0)
+				nopen++;
+		}
+	}
+	if (use_ata && nopen == 0)
+		return 0;
+	if (nopen > 0 && scgp->errstr)
+		scgp->errstr[0]=0;
+
+	if(nopen==0) for (i=0; i < 32; i++) {
+		snprintf(devname, sizeof(devname), "/dev/sg%d", i);
+		f = open(devname, O_RDWR|O_NONBLOCK);
 		if (f < 0) {
 			/*
 			 * Set up error string but let us clear it later
 			 * if at least one open succeeded.
 			 */
 			if (scgp->errstr)
-				js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+				snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 							"Cannot open '/dev/sg*'");
 			if (errno != ENOENT && errno != ENXIO && errno != ENODEV) {
 				if (scgp->errstr)
-					js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+					snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 							"Cannot open '%s'", devname);
 				return (0);
 			}
 		} else {
-			if (sg_setup(scgp, f, busno, tgt, tlun))
+			sg_clearnblock(f);
+			if (sg_setup(scgp, f, busno, tgt, tlun, -1))
 				return (++nopen);
 			if (busno < 0 && tgt < 0 && tlun < 0)
 				nopen++;
@@ -316,24 +396,25 @@ scgo_open(scgp, device)
 		scgp->errstr[0] = '\0';
 		
 	if (nopen == 0) for (i=0; i <= 25; i++) {
-		js_snprintf(devname, sizeof(devname), "/dev/sg%c", i+'a');
-		f = open(devname, 2);
+		snprintf(devname, sizeof(devname), "/dev/sg%c", i+'a');
+		f = open(devname, O_RDWR|O_NONBLOCK);
 		if (f < 0) {
 			/*
 			 * Set up error string but let us clear it later
 			 * if at least one open succeeded.
 			 */
 			if (scgp->errstr)
-				js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+				snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 							"Cannot open '/dev/sg*'");
 			if (errno != ENOENT && errno != ENXIO && errno != ENODEV) {
 				if (scgp->errstr)
-					js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+					snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 							"Cannot open '%s'", devname);
 				return (0);
 			}
 		} else {
-			if (sg_setup(scgp, f, busno, tgt, tlun))
+			sg_clearnblock(f);
+			if (sg_setup(scgp, f, busno, tgt, tlun, -1))
 				return (++nopen);
 			if (busno < 0 && tgt < 0 && tlun < 0)
 				nopen++;
@@ -344,7 +425,13 @@ scgo_open(scgp, device)
 
 openbydev:
 	if (device != NULL && *device != '\0') {
-		f = open(device, 2);
+		b = -1;
+		if(strlen(device) == 8 && strncmp(device, "/dev/hd", 7) == 0) {
+			b = device[7] - 'a';
+			if (b < 0 || b > 25)
+				b = -1;
+		}
+		f = open(device, O_RDWR|O_NONBLOCK);
 /*		if (f < 0 && errno == ENOENT)*/
 /*			goto openpg;*/
 
@@ -355,13 +442,15 @@ openbydev:
 			 * makes no sense to try the /dev/pg* driver.
 			 */
 			if (scgp->errstr)
-				js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+				snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 					"Cannot open '%s'",
 					device);
 			return (0);
 		}
 
-		if (!sg_mapdev(scgp, f, &busno, &tgt, &tlun, 0, 0)) {
+		fprintf(stderr, "Scanning device, b=%u\n", b);
+		sg_clearnblock(f);
+		if (!sg_mapdev(scgp, f, &busno, &tgt, &tlun, 0, 0, b)) {
 			close(f);
 			/*
 			 * If sg_mapdev() failes, this may be /dev/pg* device.
@@ -379,7 +468,7 @@ openbydev:
 #endif
 
 		scg_settarget(scgp, busno, tgt, tlun);
-		if (sg_setup(scgp, f, busno, tgt, tlun))
+		if (sg_setup(scgp, f, busno, tgt, tlun, b))
 			return (++nopen);
 	}
 openpg:
@@ -387,13 +476,13 @@ openpg:
 	nopen += pg_open(scgp, device);
 #endif
 	if (scgp->debug > 0) for (b=0; b < MAX_SCG; b++) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 			"Bus: %d cookie: %X\n",
 			b, scglocal(scgp)->buscookies[b]);
 		for (t=0; t < MAX_TGT; t++) {
 			for (l=0; l < MAX_LUN ; l++) {
 				if (scglocal(scgp)->scgfiles[b][t][l] != (short)-1) {
-					js_fprintf((FILE *)scgp->errfile,
+					fprintf((FILE *)scgp->errfile,
 						"file (%d,%d,%d): %d\n",
 						b, t, l, scglocal(scgp)->scgfiles[b][t][l]);
 				}
@@ -404,8 +493,7 @@ openpg:
 }
 
 LOCAL int
-scgo_close(scgp)
-	SCSI	*scgp;
+scgo_close(SCSI *scgp)
 {
 	register int	f;
 	register int	b;
@@ -439,13 +527,15 @@ scgo_close(scgp)
 	return (0);
 }
 
+LOCAL void sg_clearnblock(int f)
+{
+	int n=fcntl(f, F_GETFL);
+	n &= ~O_NONBLOCK;
+	fcntl(f, F_SETFL, n);
+}
+
 LOCAL BOOL
-sg_setup(scgp, f, busno, tgt, tlun)
-	SCSI	*scgp;
-	int	f;
-	int	busno;
-	int	tgt;
-	int	tlun;
+sg_setup(SCSI *scgp, int f, int busno, int tgt, int tlun, int ataidx)
 {
 	int	n;
 	int	Chan;
@@ -461,7 +551,7 @@ sg_setup(scgp, f, busno, tgt, tlun)
 		if (ioctl(f, SG_GET_VERSION_NUM, &n) >= 0) {
 			scglocal(scgp)->drvers = n;
 			if (scgp->overbose) {
-				js_fprintf((FILE *)scgp->errfile,
+				fprintf((FILE *)scgp->errfile,
 					"Linux sg driver version: %d.%d.%d\n",
         				n/10000, (n%10000)/100, n%100);
 			}
@@ -471,7 +561,7 @@ sg_setup(scgp, f, busno, tgt, tlun)
 	if (scg_scsibus(scgp) >= 0 && scg_target(scgp) >= 0 && scg_lun(scgp) >= 0)
 		onetarget = TRUE;
 
-	sg_mapdev(scgp, f, &Bus, &Target, &Lun, &Chan, &Ino);
+	sg_mapdev(scgp, f, &Bus, &Target, &Lun, &Chan, &Ino, ataidx);
 
 	/*
 	 * For old kernels try to make the best guess.
@@ -481,7 +571,7 @@ sg_setup(scgp, f, busno, tgt, tlun)
 	if (Bus == -1) {
 		Bus = n;
 		if (scgp->debug > 0) {
-			js_fprintf((FILE *)scgp->errfile,
+			fprintf((FILE *)scgp->errfile,
 				"SCSI Bus: %d (mapped from %d)\n", Bus, Ino);
 		}
 	}
@@ -512,15 +602,25 @@ sg_setup(scgp, f, busno, tgt, tlun)
 }
 
 LOCAL void
-sg_initdev(scgp, f)
-	SCSI	*scgp;
-	int	f;
+sg_initdev(SCSI *scgp, int f)
 {
 	struct sg_rep {
 		struct sg_header	hd;
 		unsigned char		rbuf[100];
 	} sg_rep;
 	int	n;
+	int	i;
+	struct stat sb;
+
+	sg_settimeout(f, scgp->deftimeout);
+
+	/*
+	 * If it's a block device, don't read.... pre Linux-2.4 /dev/sg*
+	 * definitely is a character device and we only need to clear the
+	 * queue for old /dev/sg* versions.
+	 */
+	if (fstat(f, &sb) >= 0 && S_ISBLK(sb.st_mode))
+		return;
 
 	/* Eat any unwanted garbage from prior use of this device */
 
@@ -539,10 +639,7 @@ sg_initdev(scgp, f)
 }
 
 LOCAL int
-sg_mapbus(scgp, busno, ino)
-	SCSI	*scgp;
-	int	busno;
-	int	ino;
+sg_mapbus(SCSI *scgp, int busno, int ino)
 {
 	register int	i;
 
@@ -575,14 +672,7 @@ sg_mapbus(scgp, busno, ino)
 }
 
 LOCAL BOOL
-sg_mapdev(scgp, f, busp, tgtp, lunp, chanp, inop)
-	SCSI	*scgp;
-	int	f;
-	int	*busp;
-	int	*tgtp;
-	int	*lunp;
-	int	*chanp;
-	int	*inop;
+sg_mapdev(SCSI *scgp, int f, int *busp, int *tgtp, int *lunp, int *chanp, int *inop, int ataidx)
 {
 	struct	sg_id {
 		long	l1; /* target | lun << 8 | channel << 16 | low_ino << 24 */
@@ -594,10 +684,24 @@ sg_mapdev(scgp, f, busp, tgtp, lunp, chanp, inop)
 	int	Target;
 	int	Lun;
 
+	if (ataidx >= 0) {
+		/* The /dev/hd* interface maps everything to
+		 * 0,0,0 so we need to do the mapping ourselves.
+		 */
+		*busp = ataidx / 2;
+		*tgtp = ataidx % 2;
+		*lunp = 0;
+		if (chanp)
+			*chanp = 0;
+		if (inop)
+			*inop = 0;
+		return (TRUE);
+	}
+
 	if (ioctl(f, SCSI_IOCTL_GET_IDLUN, &sg_id))
 		return (FALSE);
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 			"l1: 0x%lX l2: 0x%lX\n", sg_id.l1, sg_id.l2);
 	}
 	if (ioctl(f, SCSI_IOCTL_GET_BUS_NUMBER, &Bus) < 0) {
@@ -609,7 +713,7 @@ sg_mapdev(scgp, f, busp, tgtp, lunp, chanp, inop)
 	Chan	= (sg_id.l1 >> 16) & 0xFF;
 	Ino	= (sg_id.l1 >> 24) & 0xFF;
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 			"Bus: %d Target: %d Lun: %d Chan: %d Ino: %d\n",
 			Bus, Target, Lun, Chan, Ino);
 	}
@@ -636,9 +740,7 @@ sg_mapdev(scgp, f, busp, tgtp, lunp, chanp, inop)
  * is to use SG_GET_RESERVED_SIZE to read back the current values.
  */
 LOCAL long
-sg_raisedma(scgp, newmax)
-	SCSI	*scgp;
-	long	newmax;
+sg_raisedma(SCSI *scgp, long newmax)
 {
 	register int	b;
 	register int	t;
@@ -701,7 +803,7 @@ sg_raisedma(scgp, newmax)
 				if (ioctl(f, SG_GET_RESERVED_SIZE, &val) < 0)
 					continue;
 				if (scgp->debug > 0) {
-					js_fprintf((FILE *)scgp->errfile,
+					fprintf((FILE *)scgp->errfile,
 						"Target (%d,%d,%d): DMA max %d old max: %ld\n",
 						b, t, l, val, newmax);
 				}
@@ -715,9 +817,7 @@ sg_raisedma(scgp, newmax)
 #endif
 
 LOCAL long
-scgo_maxdma(scgp, amt)
-	SCSI	*scgp;
-	long	amt;
+scgo_maxdma(SCSI *scgp, long amt)
 {
 	long maxdma = MAX_DMA_LINUX;
 
@@ -757,14 +857,12 @@ scgo_maxdma(scgp, amt)
 }
 
 LOCAL void *
-scgo_getbuf(scgp, amt)
-	SCSI	*scgp;
-	long	amt;
+scgo_getbuf(SCSI *scgp, long amt)
 {
 	char	*ret;
 
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"scgo_getbuf: %ld bytes\n", amt);
 	}
 	/*
@@ -773,7 +871,7 @@ scgo_getbuf(scgp, amt)
 	 * copying the whole buffer contents when
 	 * setting up the /dev/sg data structures.
 	 */
-	ret = valloc((size_t)(amt+getpagesize()));
+	ret = (char*)valloc((size_t)(amt+getpagesize()));
 	if (ret == NULL)
 		return (ret);
 	scgp->bufbase = ret;
@@ -783,8 +881,7 @@ scgo_getbuf(scgp, amt)
 }
 
 LOCAL void
-scgo_freebuf(scgp)
-	SCSI	*scgp;
+scgo_freebuf(SCSI *scgp)
 {
 	if (scgp->bufbase)
 		free(scgp->bufbase);
@@ -792,9 +889,7 @@ scgo_freebuf(scgp)
 }
 
 LOCAL BOOL
-scgo_havebus(scgp, busno)
-	SCSI	*scgp;
-	int	busno;
+scgo_havebus(SCSI *scgp, int busno)
 {
 	register int	t;
 	register int	l;
@@ -814,11 +909,7 @@ scgo_havebus(scgp, busno)
 }
 
 LOCAL int
-scgo_fileno(scgp, busno, tgt, tlun)
-	SCSI	*scgp;
-	int	busno;
-	int	tgt;
-	int	tlun;
+scgo_fileno(SCSI *scgp, int busno, int tgt, int tlun)
 {
 	if (busno < 0 || busno >= MAX_SCG ||
 	    tgt < 0 || tgt >= MAX_TGT ||
@@ -832,8 +923,7 @@ scgo_fileno(scgp, busno, tgt, tlun)
 }
 
 LOCAL int
-scgo_initiator_id(scgp)
-	SCSI	*scgp;
+scgo_initiator_id(SCSI *scgp)
 {
 #ifdef	USE_PG
 	if (scg_scsibus(scgp) == scglocal(scgp)->pgbus)
@@ -843,14 +933,19 @@ scgo_initiator_id(scgp)
 }
 
 LOCAL int
-scgo_isatapi(scgp)
-	SCSI	*scgp;
+scgo_isatapi(SCSI *scgp)
 {
 #ifdef	USE_PG
 	if (scg_scsibus(scgp) == scglocal(scgp)->pgbus)
 		return (pg_isatapi(scgp));
 #endif
 
+	/*
+	 * The /dev/hd* interface always returns TRUE for SG_EMULATED_HOST.
+	 */
+	if (scglocal(scgp)->flags & LF_ATA)
+		return (-1);
+
 #ifdef	SG_EMULATED_HOST
 	{
 	int	emulated = FALSE;
@@ -863,9 +958,7 @@ scgo_isatapi(scgp)
 }
 
 LOCAL int
-scgo_reset(scgp, what)
-	SCSI	*scgp;
-	int	what;
+scgo_reset(SCSI *scgp, int what)
 {
 #ifdef	SG_SCSI_RESET
 	int	f = scgp->fd;
@@ -908,9 +1001,7 @@ scgo_reset(scgp, what)
 }
 
 LOCAL void
-sg_settimeout(f, tmo)
-	int	f;
-	int	tmo;
+sg_settimeout(int f, int tmo)
 {
 	tmo *= HZ;
 	if (tmo)
@@ -928,8 +1019,7 @@ sg_settimeout(f, tmo)
  */
 #ifdef	MISALIGN
 LOCAL int
-sg_getint(ip)
-	int	*ip;
+sg_getint(int *ip)
 {
 		 int	ret;
 	register char	*cp = (char *)ip;
@@ -948,8 +1038,7 @@ sg_getint(ip)
 
 #ifdef	SG_IO
 LOCAL int
-scgo_send(scgp)
-	SCSI		*scgp;
+scgo_send(SCSI *scgp)
 {
 	struct scg_cmd	*sp = scgp->scmd;
 	int		ret;
@@ -989,12 +1078,12 @@ scgo_send(scgp)
 
 	ret = ioctl(scgp->fd, SG_IO, &sg_io);
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"ioctl ret: %d\n", ret);
 	}
 
 	if (ret < 0) {
-		sp->ux_errno = geterrno();
+		sp->ux_errno = errno;
 		/*
 		 * Check if SCSI command cound not be send at all.
 		 * Linux usually returns EINVAL for an unknoen ioctl.
@@ -1016,7 +1105,7 @@ scgo_send(scgp)
 	sp->sense_count = sg_io.sb_len_wr;
 
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"host_status: %02X driver_status: %02X\n",
 				sg_io.host_status, sg_io.driver_status);
 	}
@@ -1087,8 +1176,7 @@ scgo_send(scgp)
 #endif
 
 LOCAL int
-sg_rwsend(scgp)
-	SCSI		*scgp;
+sg_rwsend(SCSI *scgp)
 {
 	int		f = scgp->fd;
 	struct scg_cmd	*sp = scgp->scmd;
@@ -1130,7 +1218,7 @@ sg_rwsend(scgp)
 			(scglocal(scgp)->SCSIbuf - (sizeof(struct sg_header)));
 	} else {
 		if (scgp->debug > 0) {
-			js_fprintf((FILE *)scgp->errfile,
+			fprintf((FILE *)scgp->errfile,
 				"DMA addr: 0x%8.8lX size: %d - using copy buffer\n",
 				(long)sp->addr, sp->size);
 		}
@@ -1138,12 +1226,12 @@ sg_rwsend(scgp)
 
 			if (scglocal(scgp)->xbuf == NULL) {
 				scglocal(scgp)->xbufsize = scgp->maxbuf;
-				scglocal(scgp)->xbuf =
+				scglocal(scgp)->xbuf = (char*)
 					malloc(scglocal(scgp)->xbufsize +
 						SCG_MAX_CMD +
 						sizeof(struct sg_header));
 				if (scgp->debug > 0) {
-					js_fprintf((FILE *)scgp->errfile,
+					fprintf((FILE *)scgp->errfile,
 						"Allocted DMA copy buffer, addr: 0x%8.8lX size: %ld\n",
 						(long)scglocal(scgp)->xbuf,
 						scgp->maxbuf);
@@ -1342,7 +1430,7 @@ sg_rwsend(scgp)
 
 	if (scgp->verbose > 0 && scgp->debug > 0) {
 #ifdef	SG_GET_BUFSIZE
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"status: 0x%08X pack_len: %d, reply_len: %d pack_id: %d result: %d wn: %d gn: %d cdb_len: %d sense_len: %d sense[0]: %02X\n",
 				GETINT(sgp->hd.sg_cmd_status),
 				GETINT(sgp->hd.pack_len),
@@ -1355,7 +1443,7 @@ sg_rwsend(scgp)
 				sgp->hd.sense_len,	
 				sgp->hd.sense_buffer[0]);
 #else
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"pack_len: %d, reply_len: %d pack_id: %d result: %d sense[0]: %02X\n",
 				GETINT(sgp->hd.pack_len),
 				GETINT(sgp->hd.reply_len),
@@ -1364,10 +1452,10 @@ sg_rwsend(scgp)
 				sgp->hd.sense_buffer[0]);
 #endif
 #ifdef	DEBUG
-		js_fprintf((FILE *)scgp->errfile, "sense: ");
+		fprintf((FILE *)scgp->errfile, "sense: ");
 		for (i=0; i < 16; i++)
-			js_fprintf((FILE *)scgp->errfile, "%02X ", sgp->hd.sense_buffer[i]);
-		js_fprintf((FILE *)scgp->errfile, "\n");
+			fprintf((FILE *)scgp->errfile, "%02X ", sgp->hd.sense_buffer[i]);
+		fprintf((FILE *)scgp->errfile, "\n");
 #endif
 	}
 
