@@ -96,7 +96,7 @@ LOCAL void
 exit_func()
 {
 	if (!close_driver())
-		js_fprintf(stderr, "Cannot close OS/2-ASPI-Router!\n");
+		fprintf(stderr, "Cannot close OS/2-ASPI-Router!\n");
 }
 
 /*
@@ -139,7 +139,7 @@ scgo_open(scgp, device)
 	if (busno >= MAX_SCG || tgt >= MAX_TGT || tlun >= MAX_LUN) {
 		errno = EINVAL;
 		if (scgp->errstr)
-			js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+			snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 				"Illegal value for busno, target or lun '%d,%d,%d'",
 				busno, tgt, tlun);
 		return (-1);
@@ -148,7 +148,7 @@ scgo_open(scgp, device)
 	if ((device != NULL && *device != '\0') || (busno == -2 && tgt == -2)) {
 		errno = EINVAL;
 		if (scgp->errstr)
-			js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+			snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 				"Open by 'devname' not supported on this OS");
 		return (-1);
 	}
@@ -194,25 +194,25 @@ scgo_getbuf(scgp, amt)
 	ULONG rc;
 
 #ifdef DEBUG
-	js_fprintf((FILE *)scgp->errfile, "scgo_getbuf: %ld bytes\n", amt);
+	fprintf((FILE *)scgp->errfile, "scgo_getbuf: %ld bytes\n", amt);
 #endif
 	rc = DosAllocMem(&buffer, amt, OBJ_TILE | PAG_READ | PAG_WRITE | PAG_COMMIT);
 
 	if (rc) {
-		js_fprintf((FILE *)scgp->errfile, "Cannot allocate buffer.\n");
+		fprintf((FILE *)scgp->errfile, "Cannot allocate buffer.\n");
 		return ((void *)0);
 	}
 	scgp->bufbase = buffer;
 
 #ifdef DEBUG
-	js_fprintf((FILE *)scgp->errfile, "Buffer allocated at: 0x%x\n", scgp->bufbase);
+	fprintf((FILE *)scgp->errfile, "Buffer allocated at: 0x%x\n", scgp->bufbase);
 #endif
 
 	/* Lock memory */
 	if (init_buffer(scgp->bufbase))
 		return (scgp->bufbase);
 
-	js_fprintf((FILE *)scgp->errfile, "Cannot lock memory buffer.\n");
+	fprintf((FILE *)scgp->errfile, "Cannot lock memory buffer.\n");
 	return ((void *)0); /* Error */
 }
 
@@ -221,7 +221,7 @@ scgo_freebuf(scgp)
 	SCSI	*scgp;
 {
 	if (scgp->bufbase && DosFreeMem(scgp->bufbase)) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 		"Cannot free buffer memory for ASPI-Router!\n"); /* Free our memory buffer if not already done */
 	}
 	if (buffer == scgp->bufbase)
@@ -306,7 +306,7 @@ static	SRB	SRBlock;			/* XXX makes it non reentrant */
 	rc = DosDevIOCtl(driver_handle, 0x92, 0x02, (void*) &SRBlock, sizeof(SRB), &cbParam,
 			(void*) &SRBlock, sizeof(SRB), &cbreturn);
 	if (rc) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"DosDevIOCtl() failed in resetDevice.\n");
 		return (1);			/* DosDevIOCtl failed */
 	} else {
@@ -317,9 +317,9 @@ static	SRB	SRBlock;			/* XXX makes it non reentrant */
 	if (SRBlock.status != SRB_Done)
 		return (3);
 #ifdef DEBUG
-	js_fprintf((FILE *)scgp->errfile,
+	fprintf((FILE *)scgp->errfile,
 		"resetDevice of host: %d target: %d lun: %d successful.\n", scg_scsibus(scgp), scg_target(scgp), scg_lun(scgp));
-	js_fprintf((FILE *)scgp->errfile,
+	fprintf((FILE *)scgp->errfile,
 		"SRBlock.ha_status: 0x%x, SRBlock.target_status: 0x%x, SRBlock.satus: 0x%x\n",
 				 SRBlock.u.cmd.ha_status, SRBlock.u.cmd.target_status, SRBlock.status);
 #endif
@@ -374,7 +374,7 @@ static	SRB	SRBlock;			/* XXX makes it non reentrant */
 	if (sp->cdb_len > sizeof(SRBlock.u.cmd.cdb_st)) { /* commandsize too big */
 		sp->error = SCG_FATAL;
 		sp->ux_errno = EINVAL;
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 			"sp->cdb_len > SRBlock.u.cmd.cdb_st. Fatal error in scgo_send, exiting...\n");
 		return (-1);
 	}
@@ -423,7 +423,7 @@ static	SRB	SRBlock;			/* XXX makes it non reentrant */
 			 (void*) &SRBlock, sizeof(SRB), &cbreturn);
 
 	if (rc) {		/* An error occured */
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"DosDevIOCtl() in sendCommand failed.\n");
 		sp->error = SCG_FATAL;
 		sp->ux_errno = EIO;	/* Spter vielleicht errno einsetzen */
@@ -436,13 +436,13 @@ static	SRB	SRBlock;			/* XXX makes it non reentrant */
 				/* Timeout */
 				sp->error = SCG_TIMEOUT;
 				sp->ux_errno = EIO;
-				js_fprintf((FILE *)scgp->errfile,
+				fprintf((FILE *)scgp->errfile,
 						"Timeout during SCSI-Command.\n");
 				return (1);
 			}
 			sp->error = SCG_FATAL;
 			sp->ux_errno = EIO;
-			js_fprintf((FILE *)scgp->errfile,
+			fprintf((FILE *)scgp->errfile,
 					"Fatal Error during DosWaitEventSem().\n");
 			return (1);
 		}
@@ -450,7 +450,7 @@ static	SRB	SRBlock;			/* XXX makes it non reentrant */
 		/* The command is processed */
 		if (SRBlock.status == SRB_Done) {	/* succesful completion */
 #ifdef DEBUG
-			js_fprintf((FILE *)scgp->errfile,
+			fprintf((FILE *)scgp->errfile,
 				"Command successful finished. SRBlock.status=0x%x\n\n", SRBlock.status);
 #endif
 			sp->sense_count = 0;
@@ -544,7 +544,7 @@ open_driver(scgp)
 			OPEN_SHARE_DENYREADWRITE | OPEN_ACCESS_READWRITE,
 			NULL);
 	if (rc) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"Cannot open ASPI-Router!\n");
 
 		return (FALSE);		/* opening failed -> return false*/
@@ -554,7 +554,7 @@ open_driver(scgp)
 	if (DosCreateEventSem(NULL, &postSema,	/* create event semaphore */
 				 DC_SEM_SHARED, 0)) {
 		DosClose(driver_handle);
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"Cannot create event semaphore!\n");
 
 		return (FALSE);
@@ -595,9 +595,9 @@ close_driver()
 			return (FALSE);		/* closing failed -> return false */
 		driver_handle = 0;
 		if (DosCloseEventSem(postSema))
-			js_fprintf(stderr, "Cannot close event semaphore!\n");
+			fprintf(stderr, "Cannot close event semaphore!\n");
 		if (buffer && DosFreeMem(buffer)) {
-			js_fprintf(stderr,
+			fprintf(stderr,
 			"Cannot free buffer memory for ASPI-Router!\n"); /* Free our memory buffer if not already done */
 		}
 		buffer = NULL;
