@@ -178,7 +178,7 @@ scgo_open(scgp, device)
 	if (busno >= MAX_SCG) {
 		errno = EINVAL;
 		if (scgp->errstr)
-			js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+			snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 				"Illegal value for busno '%d'", busno);
 		return (-1);
 	}
@@ -190,7 +190,7 @@ scgo_open(scgp, device)
 #else
 		errno = EINVAL;
 		if (scgp->errstr)
-			js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+			snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 				"Open by 'devname' not supported on this OS");
 		return (-1);
 #endif
@@ -200,7 +200,7 @@ scgo_open(scgp, device)
 		scgp->local = malloc(sizeof(struct scg_local));
 		if (scgp->local == NULL) {
 			if (scgp->errstr)
-				js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE, "No memory for scg_local");
+				snprintf(scgp->errstr, SCSI_ERRSTR_SIZE, "No memory for scg_local");
 			return (0);
 		}
 
@@ -211,12 +211,12 @@ scgo_open(scgp, device)
 
 
 	for (i=0; i < MAX_SCG; i++) {
-		js_snprintf(devname, sizeof(devname), "/dev/scg%d", i);
+		snprintf(devname, sizeof(devname), "/dev/scg%d", i);
 		f = open(devname, 2);
 		if (f < 0) {
 			if (errno != ENOENT && errno != ENXIO) {
 				if (scgp->errstr)
-					js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+					snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 						"Cannot open '%s'", devname);
 				return (-1);
 			}
@@ -443,7 +443,7 @@ scgo_uopen(scgp, device)
 	if (busno >= MAX_SCG || tgt >= MAX_TGT || tlun >= MAX_LUN) {
 		errno = EINVAL;
 		if (scgp->errstr)
-		    js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+		    snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 		       "Illegal value for busno, target or lun '%d,%d,%d'",
 		       busno, tgt, tlun);
 
@@ -453,7 +453,7 @@ scgo_uopen(scgp, device)
 		scgp->local = malloc(sizeof(struct scg_local));
 		if (scgp->local == NULL) {
 			if (scgp->errstr)
-				js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE, "No memory for scg_local");
+				snprintf(scgp->errstr, SCSI_ERRSTR_SIZE, "No memory for scg_local");
 			return (0);
 		}
 
@@ -477,11 +477,11 @@ uscsiscan:
 		if (busno >= MAX_SCG || tgt >= MAX_TGT || tlun >= MAX_LUN)
 			return (-1);
 
-		js_snprintf(devname, sizeof(devname), "/dev/rdsk/c%dt%dd%ds2",
+		snprintf(devname, sizeof(devname), "/dev/rdsk/c%dt%dd%ds2",
 			busno, tgt, tlun);
 		f = open(devname, O_RDONLY | O_NDELAY);
 		if (f < 0) {
-			js_snprintf(scgp->errstr,
+			snprintf(scgp->errstr,
 				    SCSI_ERRSTR_SIZE,
 				"Cannot open '%s'", devname);
 			return (0);
@@ -493,7 +493,7 @@ uscsiscan:
 		for (b=0; b < MAX_SCG; b++) {
 			for (t=0; t < MAX_TGT; t++) {
 				for (l=0; l < MAX_LUN ; l++) {
-					js_snprintf(devname, sizeof(devname),
+					snprintf(devname, sizeof(devname),
 						"/dev/rdsk/c%dt%dd%ds2",
 						b, t, l);
 					f = open(devname, O_RDONLY | O_NDELAY);
@@ -501,7 +501,7 @@ uscsiscan:
 							&& errno != ENXIO
 							&& errno != ENODEV) {
 						if (scgp->errstr)
-							js_snprintf(scgp->errstr,
+							snprintf(scgp->errstr,
 							    SCSI_ERRSTR_SIZE,
 							    "Cannot open '%s'", devname);
 					}
@@ -528,7 +528,7 @@ openbydev:
 
 		f = open(device, O_RDONLY | O_NDELAY);
 		if (f < 0) {
-			js_snprintf(scgp->errstr,
+			snprintf(scgp->errstr,
 				    SCSI_ERRSTR_SIZE,
 				"Cannot open '%s'", device);
 			return (0);
@@ -601,23 +601,23 @@ scgo_ucinfo(f, cp, debug)
 	if (debug <= 0)
 		return (0);
 
-	js_fprintf(stderr, "cname:		'%s'\n", cp->dki_cname);
-	js_fprintf(stderr, "ctype:		0x%04hX %hd\n", cp->dki_ctype, cp->dki_ctype);
-	js_fprintf(stderr, "cflags:		0x%04hX\n", cp->dki_flags);
-	js_fprintf(stderr, "cnum:		%hd\n", cp->dki_cnum);
+	fprintf(stderr, "cname:		'%s'\n", cp->dki_cname);
+	fprintf(stderr, "ctype:		0x%04hX %hd\n", cp->dki_ctype, cp->dki_ctype);
+	fprintf(stderr, "cflags:		0x%04hX\n", cp->dki_flags);
+	fprintf(stderr, "cnum:		%hd\n", cp->dki_cnum);
 #ifdef	__EVER__
-	js_fprintf(stderr, "addr:		%d\n", cp->dki_addr);
-	js_fprintf(stderr, "space:		%d\n", cp->dki_space);
-	js_fprintf(stderr, "prio:		%d\n", cp->dki_prio);
-	js_fprintf(stderr, "vec:		%d\n", cp->dki_vec);
+	fprintf(stderr, "addr:		%d\n", cp->dki_addr);
+	fprintf(stderr, "space:		%d\n", cp->dki_space);
+	fprintf(stderr, "prio:		%d\n", cp->dki_prio);
+	fprintf(stderr, "vec:		%d\n", cp->dki_vec);
 #endif
-	js_fprintf(stderr, "dname:		'%s'\n", cp->dki_dname);
-	js_fprintf(stderr, "unit:		%d\n", cp->dki_unit);
-	js_fprintf(stderr, "slave:		%d %04o Tgt: %d Lun: %d\n",
+	fprintf(stderr, "dname:		'%s'\n", cp->dki_dname);
+	fprintf(stderr, "unit:		%d\n", cp->dki_unit);
+	fprintf(stderr, "slave:		%d %04o Tgt: %d Lun: %d\n",
 				cp->dki_slave, cp->dki_slave,
 				TARGET(cp->dki_slave), LUN(cp->dki_slave));
-	js_fprintf(stderr, "partition:	%hd\n", cp->dki_partition);
-	js_fprintf(stderr, "maxtransfer:	%d (%d)\n",
+	fprintf(stderr, "partition:	%hd\n", cp->dki_partition);
+	fprintf(stderr, "maxtransfer:	%d (%d)\n",
 				cp->dki_maxtransfer,
 				cp->dki_maxtransfer * DEV_BSIZE);
 	return (0);
@@ -733,7 +733,7 @@ scgo_uisatapi(scgp)
 	if (ioctl(scgp->fd, DKIOCINFO, &ci) < 0)
 		return (-1);
 
-	js_snprintf(devname, sizeof(devname), "/dev/rdsk/c%dt%dd%ds2",
+	snprintf(devname, sizeof(devname), "/dev/rdsk/c%dt%dd%ds2",
 		scg_scsibus(scgp), scg_target(scgp), scg_lun(scgp));
 
 	symlinkname[0] = '\0';
@@ -805,38 +805,38 @@ scgo_usend(scgp)
 	ret = ioctl(scgp->fd, USCSICMD, &req);
 
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile, "ret: %d errno: %d (%s)\n", ret, errno, errmsgstr(errno));
-		js_fprintf((FILE *)scgp->errfile, "uscsi_flags:     0x%x\n", req.uscsi_flags);
-		js_fprintf((FILE *)scgp->errfile, "uscsi_status:    0x%x\n", req.uscsi_status);
-		js_fprintf((FILE *)scgp->errfile, "uscsi_timeout:   %d\n", req.uscsi_timeout);
-		js_fprintf((FILE *)scgp->errfile, "uscsi_bufaddr:   0x%lx\n", (long)req.uscsi_bufaddr);
-		js_fprintf((FILE *)scgp->errfile, "uscsi_buflen:    %d\n", req.uscsi_buflen);
-		js_fprintf((FILE *)scgp->errfile, "uscsi_resid:     %d\n", req.uscsi_resid);
-		js_fprintf((FILE *)scgp->errfile, "uscsi_rqlen:     %d\n", req.uscsi_rqlen);
-		js_fprintf((FILE *)scgp->errfile, "uscsi_rqstatus:  0x%x\n", req.uscsi_rqstatus);
-		js_fprintf((FILE *)scgp->errfile, "uscsi_rqresid:   %d\n", req.uscsi_rqresid);
-		js_fprintf((FILE *)scgp->errfile, "uscsi_rqbuf ptr: 0x%lx\n", (long)req.uscsi_rqbuf);
-		js_fprintf((FILE *)scgp->errfile, "uscsi_rqbuf:     ");
+		fprintf((FILE *)scgp->errfile, "ret: %d errno: %d (%s)\n", ret, errno, strerror(errno));
+		fprintf((FILE *)scgp->errfile, "uscsi_flags:     0x%x\n", req.uscsi_flags);
+		fprintf((FILE *)scgp->errfile, "uscsi_status:    0x%x\n", req.uscsi_status);
+		fprintf((FILE *)scgp->errfile, "uscsi_timeout:   %d\n", req.uscsi_timeout);
+		fprintf((FILE *)scgp->errfile, "uscsi_bufaddr:   0x%lx\n", (long)req.uscsi_bufaddr);
+		fprintf((FILE *)scgp->errfile, "uscsi_buflen:    %d\n", req.uscsi_buflen);
+		fprintf((FILE *)scgp->errfile, "uscsi_resid:     %d\n", req.uscsi_resid);
+		fprintf((FILE *)scgp->errfile, "uscsi_rqlen:     %d\n", req.uscsi_rqlen);
+		fprintf((FILE *)scgp->errfile, "uscsi_rqstatus:  0x%x\n", req.uscsi_rqstatus);
+		fprintf((FILE *)scgp->errfile, "uscsi_rqresid:   %d\n", req.uscsi_rqresid);
+		fprintf((FILE *)scgp->errfile, "uscsi_rqbuf ptr: 0x%lx\n", (long)req.uscsi_rqbuf);
+		fprintf((FILE *)scgp->errfile, "uscsi_rqbuf:     ");
 		if (req.uscsi_rqbuf != NULL && req.uscsi_rqlen > req.uscsi_rqresid) {
 			int	i;
 			int	len = req.uscsi_rqlen - req.uscsi_rqresid;
 
 			for (i = 0; i < len; i++) {
-				js_fprintf((FILE *)scgp->errfile, "0x%02X ", ((char *)req.uscsi_rqbuf)[i]);
+				fprintf((FILE *)scgp->errfile, "0x%02X ", ((char *)req.uscsi_rqbuf)[i]);
 			}		
-			js_fprintf((FILE *)scgp->errfile, "\n");
+			fprintf((FILE *)scgp->errfile, "\n");
 		} else {
-			js_fprintf((FILE *)scgp->errfile, "<data not available>\n");
+			fprintf((FILE *)scgp->errfile, "<data not available>\n");
 		}
 	}
 	if (ret < 0) {
-		sp->ux_errno = geterrno();
+		sp->ux_errno = errno;
 		/*
 		 * Check if SCSI command cound not be send at all.
 		 */
 		if (sp->ux_errno == ENOTTY && scgo_uisatapi(scgp) == TRUE) {
 			if (scgp->debug > 0) {
-				js_fprintf((FILE *)scgp->errfile,
+				fprintf((FILE *)scgp->errfile,
 					"ENOTTY atapi: %d\n", scgo_uisatapi(scgp));
 			}
 			sp->error = SCG_FATAL;
