@@ -162,7 +162,7 @@ scgo_open(scgp, device)
 	if (busno >= MAX_SCG || tgt >= MAX_TGT || tlun >= MAX_LUN) {
 		errno = EINVAL;
 		if (scgp->errstr)
-			js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+			snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 				"Illegal value for busno, target or lun '%d,%d,%d'",
 				busno, tgt, tlun);
 		return (-1);
@@ -171,7 +171,7 @@ scgo_open(scgp, device)
 	if ((device != NULL && *device != '\0') || (busno == -2 && tgt == -2)) {
 		errno = EINVAL;
 		if (scgp->errstr)
-			js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+			snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 				"Open by 'devname' not supported on this OS");
 		return (-1);
 	}
@@ -241,7 +241,7 @@ scgo_getbuf(scgp, amt)
 	long	amt;
 {
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"scgo_getbuf: %ld bytes\n", amt);
 	}
 	scgp->bufbase = malloc((size_t)(amt));
@@ -330,7 +330,7 @@ scgo_reset(scgp, what)
 	 * XXX Does this reset TGT or BUS ???
 	 */
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"Attempting to reset SCSI device\n");
 	}
 
@@ -338,7 +338,7 @@ scgo_reset(scgp, what)
 	 * Check if ASPI library is loaded
 	 */
 	if (AspiLoaded == FALSE) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"error in scgo_reset: ASPI driver not loaded !\n");
 		return (-1);
 	}
@@ -393,7 +393,7 @@ scgo_reset(scgp, what)
 	 * Check condition
 	 */
 	if (s.SRB_Status != SS_COMP) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 					"ERROR! 0x%08X\n", s.SRB_Status);
 
 		/*
@@ -403,7 +403,7 @@ scgo_reset(scgp, what)
 	}
 
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 					"Reset SCSI device completed\n");
 	}
 
@@ -423,34 +423,34 @@ DebugScsiSend(scgp, s, bDisplayBuffer)
 {
 	int i;
 
-	js_fprintf((FILE *)scgp->errfile, "\n\nDebugScsiSend\n");
-	js_fprintf((FILE *)scgp->errfile, "s.SRB_Cmd          = 0x%02x\n", s.SRB_Cmd);
-	js_fprintf((FILE *)scgp->errfile, "s.SRB_HaId         = 0x%02x\n", s.SRB_HaId);
-	js_fprintf((FILE *)scgp->errfile, "s.SRB_Flags        = 0x%02x\n", s.SRB_Flags); 
-	js_fprintf((FILE *)scgp->errfile, "s.SRB_Target       = 0x%02x\n", s.SRB_Target); 
-	js_fprintf((FILE *)scgp->errfile, "s.SRB_Lun          = 0x%02x\n", s.SRB_Lun);
-	js_fprintf((FILE *)scgp->errfile, "s.SRB_BufLen       = 0x%02x\n", s.SRB_BufLen);
-	js_fprintf((FILE *)scgp->errfile, "s.SRB_BufPointer   = %x\n",     s.SRB_BufPointer);
-	js_fprintf((FILE *)scgp->errfile, "s.SRB_CDBLen       = 0x%02x\n", s.SRB_CDBLen);
-	js_fprintf((FILE *)scgp->errfile, "s.SRB_SenseLen     = 0x%02x\n", s.SRB_SenseLen);
-	js_fprintf((FILE *)scgp->errfile, "s.CDBByte          =");
+	fprintf((FILE *)scgp->errfile, "\n\nDebugScsiSend\n");
+	fprintf((FILE *)scgp->errfile, "s.SRB_Cmd          = 0x%02x\n", s.SRB_Cmd);
+	fprintf((FILE *)scgp->errfile, "s.SRB_HaId         = 0x%02x\n", s.SRB_HaId);
+	fprintf((FILE *)scgp->errfile, "s.SRB_Flags        = 0x%02x\n", s.SRB_Flags); 
+	fprintf((FILE *)scgp->errfile, "s.SRB_Target       = 0x%02x\n", s.SRB_Target); 
+	fprintf((FILE *)scgp->errfile, "s.SRB_Lun          = 0x%02x\n", s.SRB_Lun);
+	fprintf((FILE *)scgp->errfile, "s.SRB_BufLen       = 0x%02x\n", s.SRB_BufLen);
+	fprintf((FILE *)scgp->errfile, "s.SRB_BufPointer   = %x\n",     s.SRB_BufPointer);
+	fprintf((FILE *)scgp->errfile, "s.SRB_CDBLen       = 0x%02x\n", s.SRB_CDBLen);
+	fprintf((FILE *)scgp->errfile, "s.SRB_SenseLen     = 0x%02x\n", s.SRB_SenseLen);
+	fprintf((FILE *)scgp->errfile, "s.CDBByte          =");
 	for (i=0; i < min(s.SRB_CDBLen, 16); i++) {
-		js_fprintf((FILE *)scgp->errfile, " %02X ", s.CDBByte[i]);
+		fprintf((FILE *)scgp->errfile, " %02X ", s.CDBByte[i]);
 	}
-	js_fprintf((FILE *)scgp->errfile, "\n");
+	fprintf((FILE *)scgp->errfile, "\n");
 
 	/*
 	if (bDisplayBuffer != 0 && s.SRB_BufLen >= 8) {
 		
-		js_fprintf((FILE *)scgp->errfile, "s.SRB_BufPointer   =");
+		fprintf((FILE *)scgp->errfile, "s.SRB_BufPointer   =");
 		for (i=0; i < 8; i++) {
-			js_fprintf((FILE *)scgp->errfile,
+			fprintf((FILE *)scgp->errfile,
 					" %02X ", ((char*)s.SRB_BufPointer)[i]);
 		}
-		js_fprintf((FILE *)scgp->errfile, "\n");
+		fprintf((FILE *)scgp->errfile, "\n");
 	}
 */
-	js_fprintf((FILE *)scgp->errfile, "Debug done\n");
+	fprintf((FILE *)scgp->errfile, "Debug done\n");
 }
 #endif
 
@@ -585,7 +585,7 @@ scgo_send(scgp)
 	if (sp->cdb_len > 16) {
 		sp->error = SCG_FATAL;
 		sp->ux_errno = EINVAL;
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 			"sp->cdb_len > sizeof(SRB_ExecSCSICmd.CDBByte). Fatal error in scgo_send, exiting...\n");
 		return (-1);
 	}
@@ -652,7 +652,7 @@ scgo_send(scgp)
 
 		if (s.SRB_Status == SS_PENDING) {/* Check if we got a timeout*/
 			if (scgp->debug > 0) {
-				js_fprintf((FILE *)scgp->errfile,
+				fprintf((FILE *)scgp->errfile,
 						"Timeout....\n");
 			}
 			scsiabort(scgp, &s);
@@ -670,7 +670,7 @@ scgo_send(scgp)
 	 */
 	if (s.SRB_Status != SS_COMP) {
 		if (scgp->debug > 0) {
-			js_fprintf((FILE *)scgp->errfile,
+			fprintf((FILE *)scgp->errfile,
 				"Error in scgo_send: s.SRB_Status is 0x%x\n", s.SRB_Status);
 		}
 
@@ -678,7 +678,7 @@ scgo_send(scgp)
 		copy_sensedata(&s, sp);		/* Copy sense and status     */
 
 		if (scgp->debug > 0) {
-			js_fprintf((FILE *)scgp->errfile,
+			fprintf((FILE *)scgp->errfile,
 				"Mapped to: error %d errno: %d\n", sp->error, sp->ux_errno);
 		}
 		return (1);
@@ -712,7 +712,7 @@ open_driver(scgp)
 	int	i;
 
 #ifdef DEBUG_WNTASPI
-	js_fprintf((FILE *)scgp->errfile, "enter open_driver\n");
+	fprintf((FILE *)scgp->errfile, "enter open_driver\n");
 #endif
 
 	/*
@@ -734,7 +734,7 @@ open_driver(scgp)
 	 * Check if ASPI library is loaded correctly
 	 */
 	if (hAspiLib == NULL) {
-		js_fprintf((FILE *)scgp->errfile, "Can not load ASPI driver! ");
+		fprintf((FILE *)scgp->errfile, "Can not load ASPI driver! ");
 		return (FALSE);
 	}
   
@@ -751,7 +751,7 @@ open_driver(scgp)
 #endif
 
 	if ((pfnGetASPI32SupportInfo == NULL) || (pfnSendASPI32Command == NULL)) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"ASPI function not found in library!");
 		return (FALSE);
 	}
@@ -777,20 +777,20 @@ open_driver(scgp)
 	HACount    = LOBYTE(LOWORD(astatus));
 
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 			"open_driver %X HostASPIStatus=0x%x HACount=0x%x\n", astatus, ASPIStatus, HACount);
 	}
 
 	if (ASPIStatus != SS_COMP && ASPIStatus != SS_NO_ADAPTERS) {
-		js_fprintf((FILE *)scgp->errfile, "Could not find any host adapters\n");
-		js_fprintf((FILE *)scgp->errfile, "ASPIStatus == 0x%02X", ASPIStatus);
+		fprintf((FILE *)scgp->errfile, "Could not find any host adapters\n");
+		fprintf((FILE *)scgp->errfile, "ASPIStatus == 0x%02X", ASPIStatus);
 		return (FALSE);
 	}
 	busses = HACount;
 
 #ifdef DEBUG_WNTASPI
-	js_fprintf((FILE *)scgp->errfile, "open_driver HostASPIStatus=0x%x HACount=0x%x\n", ASPIStatus, HACount);
-	js_fprintf((FILE *)scgp->errfile, "leaving open_driver\n");
+	fprintf((FILE *)scgp->errfile, "open_driver HostASPIStatus=0x%x HACount=0x%x\n", ASPIStatus, HACount);
+	fprintf((FILE *)scgp->errfile, "leaving open_driver\n");
 #endif
 
 	for (i=0; i < busses; i++) {
@@ -868,11 +868,11 @@ ha_inquiry(scgp, id, ip)
 	Status = pfnSendASPI32Command((LPSRB)ip);
 
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile, "Status : %d\n",	Status);
-		js_fprintf((FILE *)scgp->errfile, "hacount: %d\n", ip->HA_Count);
-		js_fprintf((FILE *)scgp->errfile, "SCSI id: %d\n", ip->HA_SCSI_ID);
-		js_fprintf((FILE *)scgp->errfile, "Manager: '%.16s'\n", ip->HA_ManagerId);
-		js_fprintf((FILE *)scgp->errfile, "Identif: '%.16s'\n", ip->HA_Identifier);
+		fprintf((FILE *)scgp->errfile, "Status : %d\n",	Status);
+		fprintf((FILE *)scgp->errfile, "hacount: %d\n", ip->HA_Count);
+		fprintf((FILE *)scgp->errfile, "SCSI id: %d\n", ip->HA_SCSI_ID);
+		fprintf((FILE *)scgp->errfile, "Manager: '%.16s'\n", ip->HA_ManagerId);
+		fprintf((FILE *)scgp->errfile, "Identif: '%.16s'\n", ip->HA_Identifier);
 		scg_prbytes("Unique:", ip->HA_Unique, 16);
 	}
 	if (ip->SRB_Status != SS_COMP)
@@ -889,7 +889,7 @@ resetSCSIBus(scgp)
 	HANDLE			Event;
 	SRB_BusDeviceReset	s;
 
-	js_fprintf((FILE *)scgp->errfile, "Attempting to reset SCSI bus\n");
+	fprintf((FILE *)scgp->errfile, "Attempting to reset SCSI bus\n");
 
 	Event = CreateEvent(NULL, TRUE, FALSE, NULL);
 
@@ -930,7 +930,7 @@ resetSCSIBus(scgp)
 	 * Check condition
 	 */
 	if (s.SRB_Status != SS_COMP) {
-		js_fprintf((FILE *)scgp->errfile, "ERROR  0x%08X\n", s.SRB_Status);
+		fprintf((FILE *)scgp->errfile, "ERROR  0x%08X\n", s.SRB_Status);
 
 		/*
 		 * Indicate that error has occured
@@ -954,7 +954,7 @@ scsiabort(scgp, sp)
 	SRB_Abort		s;
 
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"Attempting to abort SCSI command\n");
 	}
 
@@ -962,7 +962,7 @@ scsiabort(scgp, sp)
 	 * Check if ASPI library is loaded
 	 */
 	if (AspiLoaded == FALSE) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 				"error in scsiabort: ASPI driver not loaded !\n");
 		return (FALSE);
 	}
@@ -984,7 +984,7 @@ scsiabort(scgp, sp)
 	 * Check condition
 	 */
 	if (s.SRB_Status != SS_COMP) {
-		js_fprintf((FILE *)scgp->errfile, "Abort ERROR! 0x%08X\n", s.SRB_Status);
+		fprintf((FILE *)scgp->errfile, "Abort ERROR! 0x%08X\n", s.SRB_Status);
 
 		/*
 		 * Indicate that error has occured
@@ -993,7 +993,7 @@ scsiabort(scgp, sp)
 	}
 
 	if (scgp->debug > 0)
-		js_fprintf((FILE *)scgp->errfile, "Abort SCSI command completed\n");
+		fprintf((FILE *)scgp->errfile, "Abort SCSI command completed\n");
 
 	/*
 	 * Everything went OK
