@@ -470,13 +470,7 @@ static char *sd_cmds[] = {
 
 EXPORT
 const char *
-scg_sensemsg(ctype, code, qual, vec, sbuf, maxcnt)
-	register 	int	ctype;
-	register 	int	code;
-	register 	int	qual;
-	register const char	**vec;
-			char	*sbuf;
-			int	maxcnt;
+scg_sensemsg(int ctype, int code, int qual, const char **vec, char *sbuf, int maxcnt)
 {
 	register int i;
 
@@ -521,18 +515,18 @@ scg_sensemsg(ctype, code, qual, vec, sbuf, maxcnt)
 			vec = sd_ccs_error_str;
 	}
 	if (code == 0x40) {
-		js_snprintf(sbuf, maxcnt,
+		snprintf(sbuf, maxcnt,
 			"diagnostic failure on component 0x%X", qual);
 		return (sbuf);
 	}
 	if (code == 0x4D) {
-		js_snprintf(sbuf, maxcnt,
+		snprintf(sbuf, maxcnt,
 			"tagged overlapped commands, queue tag is 0x%X",
 									qual);
 		return (sbuf);
 	}
 	if (code == 0x70) {
-		js_snprintf(sbuf, maxcnt,
+		snprintf(sbuf, maxcnt,
 			"decompression exception short algorithm id of 0x%X",
 									qual);
 		return (sbuf);
@@ -541,22 +535,16 @@ scg_sensemsg(ctype, code, qual, vec, sbuf, maxcnt)
 		return ((char *)NULL);
 
 	if (code < 0x80) {
-		js_snprintf(sbuf, maxcnt, "invalid sense code 0x%X", code);
+		snprintf(sbuf, maxcnt, "invalid sense code 0x%X", code);
 		return (sbuf);
 	}
-	js_snprintf(sbuf, maxcnt, "vendor unique sense code 0x%X", code);
+	snprintf(sbuf, maxcnt, "vendor unique sense code 0x%X", code);
 	return (sbuf);
 }
 
 #undef	sense	/*XXX JS Hack, solange scgio.h noch nicht fertig ist */
 EXPORT int
-scg__errmsg(scgp, obuf, maxcnt, sense, status, sense_code)
-	SCSI	*scgp;
-	char	*obuf;
-	int	maxcnt;
-	register struct scsi_sense	*sense;
-	register struct scsi_status	*status;
-	int				sense_code;
+scg__errmsg(SCSI *scgp, char *obuf, int maxcnt, struct scsi_sense *sense, struct scsi_status *status, int sense_code)
 {
 	char	sbuf[80];
 	const char *sensemsg, *cmdname, *sensekey;
@@ -629,7 +617,7 @@ scg__errmsg(scgp, obuf, maxcnt, sense, status, sense_code)
 	}
 */
 	cmdname = "";
-	n = js_snprintf(obuf, sizeleft, "%sSense Key: 0x%X %s%s, Segment %d\n",
+	n = snprintf(obuf, sizeleft, "%sSense Key: 0x%X %s%s, Segment %d\n",
 		cmdname, key, sensekey,
 		(sense->code == 0x71)?", deferred error":"",
 		segment);
@@ -639,7 +627,7 @@ scg__errmsg(scgp, obuf, maxcnt, sense, status, sense_code)
 	}
 	obuf += n;
 	sizeleft -= n;
-	n = js_snprintf(obuf, sizeleft, "Sense Code: 0x%02X Qual 0x%02X %s%s%s%s Fru 0x%X\n",
+	n = snprintf(obuf, sizeleft, "Sense Code: 0x%02X Qual 0x%02X %s%s%s%s Fru 0x%X\n",
 		code, qual, *sensemsg?"(":"", sensemsg, *sensemsg?")":"",
 		badqual? " [No matching qualifier]":"",
 		fru);
@@ -649,7 +637,7 @@ scg__errmsg(scgp, obuf, maxcnt, sense, status, sense_code)
 	}
 	obuf += n;
 	sizeleft -= n;
-	n = js_snprintf(obuf, sizeleft, "Sense flags: Blk %d %s%s%s%s",
+	n = snprintf(obuf, sizeleft, "Sense flags: Blk %d %s%s%s%s",
 		blkno, blkvalid?"(valid) ":"(not valid) ",
 		fm?"file mark detected ":"",
 		eom?"end of medium ":"",
@@ -661,7 +649,7 @@ scg__errmsg(scgp, obuf, maxcnt, sense, status, sense_code)
 	obuf += n;
 	sizeleft -= n;
 	if (!sksv) {
-		n = js_snprintf(obuf, sizeleft, "\n");
+		n = snprintf(obuf, sizeleft, "\n");
 		if (n <= 0) {
 			obuf[0] = '\0';
 			return (maxcnt - sizeleft);
@@ -673,7 +661,7 @@ scg__errmsg(scgp, obuf, maxcnt, sense, status, sense_code)
 	switch (key) {
 
 	case SC_ILLEGAL_REQUEST:
-		n = js_snprintf(obuf, sizeleft, "error refers to %s part, bit ptr %d %s field ptr %d",
+		n = snprintf(obuf, sizeleft, "error refers to %s part, bit ptr %d %s field ptr %d",
 			ext_sense->cd? "command":"data",
 			ext_sense->bptr,
 			ext_sense->bpv? "(valid)":"(not valid)",
@@ -690,7 +678,7 @@ scg__errmsg(scgp, obuf, maxcnt, sense, status, sense_code)
 	case SC_RECOVERABLE_ERROR:
 	case SC_HARDWARE_ERROR:
 	case SC_MEDIUM_ERROR:
-		n = js_snprintf(obuf, sizeleft, "actual retry count %d",
+		n = snprintf(obuf, sizeleft, "actual retry count %d",
 			ext_sense->field_ptr[0] << 8 |
 			ext_sense->field_ptr[1]);
 		if (n <= 0) {
@@ -702,7 +690,7 @@ scg__errmsg(scgp, obuf, maxcnt, sense, status, sense_code)
 		break;
 
 	case SC_NOT_READY:
-		n = js_snprintf(obuf, sizeleft, "operation %d%% done",
+		n = snprintf(obuf, sizeleft, "operation %d%% done",
 			(100*(ext_sense->field_ptr[0] << 8 |
 			      ext_sense->field_ptr[1]))/(unsigned)65536);
 		if (n < 0) {
@@ -713,7 +701,7 @@ scg__errmsg(scgp, obuf, maxcnt, sense, status, sense_code)
 		sizeleft -= n;
 		break;
 	}
-	n = js_snprintf(obuf, sizeleft, "\n");
+	n = snprintf(obuf, sizeleft, "\n");
 	if (n <= 0) {
 		obuf[0] = '\0';
 		return (maxcnt - sizeleft);
@@ -724,7 +712,7 @@ scg__errmsg(scgp, obuf, maxcnt, sense, status, sense_code)
 }
 
 #ifdef	DEBUG
-print_err(code, ctype)
+print_err(unsigned char code, int ctype)
 {
 	register int i;
 	register char **vec  = (char **)NULL;
@@ -751,14 +739,14 @@ print_err(code, ctype)
 		break;
 #endif
 	}
-	js_printf("error code: 0x%x", code);
+	printf("error code: 0x%x", code);
 	if (vec == (char **)NULL)
 		return;
 
 	for (i = 0; i < 2; i++) {
 		while (*vec != (char *) NULL) {
 			if (code == (Uchar)*vec[0]) {
-				js_printf(" (%s)", (char *)((int)(*vec)+1));
+				printf(" (%s)", (char *)((int)(*vec)+1));
 				return;
 			} else
 				vec++;
@@ -775,18 +763,18 @@ main()
 
 #ifdef ACB
 	for (i = 0; i < 0x30; i++) {
-/*		js_printf("Code: 0x%x	Key: 0x%x	", i, sd_adaptec_keys[i]);*/
-		js_printf("Key: 0x%x %-16s ", sd_adaptec_keys[i],
+/*		printf("Code: 0x%x	Key: 0x%x	", i, sd_adaptec_keys[i]);*/
+		printf("Key: 0x%x %-16s ", sd_adaptec_keys[i],
 					sd_sense_keys[sd_adaptec_keys[i]] );
 		js_print_err(i, CTYPE_ACB4000);
-		js_printf("\n");
+		printf("\n");
 	}
 #else
 /*	for (i = 0; i < 0x84; i++) {*/
 	for (i = 0; i < 0xd8; i++) {
 /*		print_err(i, CTYPE_SMO_C501);*/
 		print_err(i, DEV_CDD_521);
-		js_printf("\n");
+		printf("\n");
 	}
 #endif
 }
