@@ -327,9 +327,7 @@ LOCAL	char	_scg_trans_dversion[] = "scsihack.c-1.40";	/* The version for this tr
  * in applications.
  */
 LOCAL char *
-scgo_dversion(scgp, what)
-	SCSI	*scgp;
-	int	what;
+scgo_dversion(SCSI *scgp, int what)
 {
 	if (scgp != (SCSI *)0) {
 		switch (what) {
@@ -350,9 +348,7 @@ scgo_dversion(scgp, what)
 }
 
 LOCAL int
-scgo_ropen(scgp, device)
-	SCSI	*scgp;
-	char	*device;
+scgo_ropen(SCSI *scgp, char *device)
 {
 	comerrno(EX_BAD, "No remote SCSI transport available.\n");
 	return (-1);	/* Keep lint happy */
@@ -360,18 +356,14 @@ scgo_ropen(scgp, device)
 
 #ifndef	SCSI_IMPL
 LOCAL int
-scgo_dopen(scgp, device)
-	SCSI	*scgp;
-	char	*device;
+scgo_dopen(SCSI *scgp, char *device)
 {
 	comerrno(EX_BAD, "No local SCSI transport implementation for this architecture.\n");
 	return (-1);	/* Keep lint happy */
 }
 #else
 LOCAL int
-scgo_dopen(scgp, device)
-	SCSI	*scgp;
-	char	*device;
+scgo_dopen(SCSI *scgp, char *device)
 {
 	comerrno(EX_BAD, "SCSI open usage error.\n");
 	return (-1);	/* Keep lint happy */
@@ -379,81 +371,64 @@ scgo_dopen(scgp, device)
 #endif	/* SCSI_IMPL */
 
 LOCAL int
-scgo_dclose(scgp)
-	SCSI	*scgp;
+scgo_dclose(SCSI *scgp)
 {
 	errno = EINVAL;
 	return (-1);
 }
 
 LOCAL long
-scgo_dmaxdma(scgp, amt)
-	SCSI	*scgp;
-	long	amt;
+scgo_dmaxdma(SCSI *scgp, long amt)
 {
 	errno = EINVAL;
 	return	(0L);
 }
 
 LOCAL void *
-scgo_dgetbuf(scgp, amt)
-	SCSI	*scgp;
-	long	amt;
+scgo_dgetbuf(SCSI *scgp, long amt)
 {
 	errno = EINVAL;
 	return ((void *)0);
 }
 
 LOCAL void
-scgo_dfreebuf(scgp)
-	SCSI	*scgp;
+scgo_dfreebuf(SCSI *scgp)
 {
 }
 
 LOCAL BOOL
-scgo_dhavebus(scgp, busno)
-	SCSI	*scgp;
-	int	busno;
+scgo_dhavebus(SCSI *scgp, int busno)
 {
 	return (FALSE);
 }
 
 LOCAL int
-scgo_dfileno(scgp, busno, tgt, tlun)
-	SCSI	*scgp;
-	int	busno;
-	int	tgt;
-	int	tlun;
+scgo_dfileno(SCSI *scgp, int busno, int tgt, int tlun)
 {
 	return (-1);
 }
 
 LOCAL int
-scgo_dinitiator_id(scgp)
-	SCSI	*scgp;
+scgo_dinitiator_id(SCSI *scgp)
 {
 	return (-1);
 }
 
 LOCAL int
-scgo_disatapi(scgp)
-	SCSI	*scgp;
+scgo_disatapi(SCSI *scgp)
 {
 	return (FALSE);
 }
 
 LOCAL int
-scgo_dreset(scgp, what)
-	SCSI	*scgp;
-	int	what;
+scgo_dreset(SCSI *scgp, int what)
 {
 	errno = EINVAL;
 	return (-1);
 }
 
 LOCAL int
-scgo_dsend(scgp)
-	SCSI	*scgp;
+scgo_dsend(SCSI *scgp)
 {
 	errno = EINVAL;
 	return (-1);
