@@ -123,18 +123,10 @@ LOCAL	int	prc    __PR((char, f_args *));
 LOCAL	int	prstring __PR((const char *, f_args *));
 
 
-#ifdef	PROTOTYPES
 EXPORT int format(	void (*fun)(char, long),
 			long farg,
 			const char *fmt,
 			va_list args)
-#else
-EXPORT int format(fun, farg, fmt, args)
-	register void	(*fun)();
-	register long	farg;
-	register char	*fmt;
-	va_list		args;
-#endif
 {
 	char buf[512];
 	const char *sfmt;
@@ -623,10 +615,7 @@ EXPORT int format(fun, farg, fmt, args)
 LOCAL	unsigned char	dtab[]  = "0123456789abcdef";
 LOCAL	unsigned char	udtab[] = "0123456789ABCDEF";
 
-LOCAL void prnum(val, base, fa)
-	register Ulong val;
-	register unsigned base;
-	f_args *fa;
+LOCAL void prnum(Ulong val, unsigned base, f_args *fa)
 {
 	register char *p = fa->bufp;
 
@@ -638,9 +627,7 @@ LOCAL void prnum(val, base, fa)
 	fa->bufp = p;
 }
 
-LOCAL void prdnum(val, fa)
-	register Ulong val;
-	f_args *fa;
+LOCAL void prdnum(Ulong val, f_args *fa)
 {
 	register char *p = fa->bufp;
 
@@ -655,9 +642,7 @@ LOCAL void prdnum(val, fa)
 /*
  * We may need to use division here too (PDP-11, non two's complement ...)
  */
-LOCAL void pronum(val, fa)
-	register Ulong val;
-	f_args *fa;
+LOCAL void pronum(Ulong val, f_args *fa)
 {
 	register char *p = fa->bufp;
 
@@ -669,9 +654,7 @@ LOCAL void pronum(val, fa)
 	fa->bufp = p;
 }
 
-LOCAL void prxnum(val, fa)
-	register Ulong val;
-	f_args *fa;
+LOCAL void prxnum(Ulong val, f_args *fa)
 {
 	register char *p = fa->bufp;
 
@@ -683,9 +666,7 @@ LOCAL void prxnum(val, fa)
 	fa->bufp = p;
 }
 
-LOCAL void prXnum(val, fa)
-	register Ulong val;
-	f_args *fa;
+LOCAL void prXnum(Ulong val, f_args *fa)
 {
 	register char *p = fa->bufp;
 
@@ -698,10 +679,7 @@ LOCAL void prXnum(val, fa)
 }
 
 #ifdef	USE_LONGLONG
-LOCAL void prlnum(val, base, fa)
-	register Ullong val;
-	register unsigned base;
-	f_args *fa;
+LOCAL void prlnum(Ullong val, unsigned base, f_args *fa)
 {
 	register char *p = fa->bufp;
 
@@ -713,9 +691,7 @@ LOCAL void prlnum(val, base, fa)
 	fa->bufp = p;
 }
 
-LOCAL void prldnum(val, fa)
-	register Ullong val;
-	f_args *fa;
+LOCAL void prldnum(Ullong val, f_args *fa)
 {
 	register char *p = fa->bufp;
 
@@ -727,9 +703,7 @@ LOCAL void prldnum(val, fa)
 	fa->bufp = p;
 }
 
-LOCAL void prlonum(val, fa)
-	register Ullong val;
-	f_args *fa;
+LOCAL void prlonum(Ullong val, f_args *fa)
 {
 	register char *p = fa->bufp;
 
@@ -741,9 +715,7 @@ LOCAL void prlonum(val, fa)
 	fa->bufp = p;
 }
 
-LOCAL void prlxnum(val, fa)
-	register Ullong val;
-	f_args *fa;
+LOCAL void prlxnum(Ullong val, f_args *fa)
 {
 	register char *p = fa->bufp;
 
@@ -755,9 +727,7 @@ LOCAL void prlxnum(val, fa)
 	fa->bufp = p;
 }
 
-LOCAL void prlXnum(val, fa)
-	register Ullong val;
-	f_args *fa;
+LOCAL void prlXnum(Ullong val, f_args *fa)
 {
 	register char *p = fa->bufp;
 
@@ -774,9 +744,7 @@ LOCAL void prlXnum(val, fa)
 /*
  * Final buffer print out routine.
  */
-LOCAL int prbuf(s, fa)
-	register const char *s;
-	f_args *fa;
+LOCAL int prbuf(const char *s, f_args *fa)
 {
 	register int diff;
 	register int rfillc;
@@ -829,15 +797,8 @@ LOCAL int prbuf(s, fa)
  * Print out one char, allowing prc('\0')
  * Similar to prbuf()
  */
-#ifdef	PROTOTYPES
 
 LOCAL int prc(char c, f_args *fa)
-
-#else
-LOCAL int prc(c, fa)
-	char	c;
-	f_args *fa;
-#endif
 {
 	register int diff;
 	register int rfillc;
@@ -869,9 +830,7 @@ LOCAL int prc(c, fa)
  * If fa->signific is >= 0, it uses only fa->signific chars.
  * If fa->signific is 0, print no characters.
  */
-LOCAL int prstring(s, fa)
-	register const char	*s;
-	f_args *fa;
+LOCAL int prstring(const char *s, f_args *fa)
 {
 	register char	*bp;
 	register int	signific;
