@@ -37,62 +37,32 @@ LOCAL	int	_serrmsg	__PR((int, char *buf, size_t maxcnt, const char *, va_list));
 
 /* VARARGS1 */
 EXPORT int
-#ifdef	PROTOTYPES
 serrmsg(char *buf, size_t maxcnt, const char *msg, ...)
-#else
-serrmsg(buf, maxcnt, msg, va_alist)
-	char	*buf;
-	size_t	maxcnt;
-	char	*msg;
-	va_dcl
-#endif
 {
 	va_list	args;
 	int	ret;
 
-#ifdef	PROTOTYPES
 	va_start(args, msg);
-#else
-	va_start(args);
-#endif
 	ret = _serrmsg(errno, buf, maxcnt, msg, args);
 	va_end(args);
 	return (ret);
 }
 
 /* VARARGS2 */
-#ifdef	PROTOTYPES
 EXPORT int
 serrmsgno(int err, char *buf, size_t maxcnt, const char *msg, ...)
-#else
-serrmsgno(err, buf, maxcnt, msg, va_alist)
-	int	err;
-	char	*buf;
-	size_t	maxcnt;
-	char	*msg;
-	va_dcl
-#endif
 {
 	va_list	args;
 	int	ret;
 
-#ifdef	PROTOTYPES
 	va_start(args, msg);
-#else
-	va_start(args);
-#endif
 	ret = _serrmsg(err, buf, maxcnt, msg, args);
 	va_end(args);
 	return (ret);
 }
 
 LOCAL int
-_serrmsg(err, buf, maxcnt, msg, args)
-	int		err;
-	char		*buf;
-	size_t		maxcnt;
-	const char	*msg;
-	va_list		args;
+_serrmsg(int err, char *buf, size_t maxcnt, const char *msg, va_list args)
 {
 	int	ret;
 	char	errbuf[20];
