@@ -567,12 +567,12 @@ dump_stat(extent)
   sprintf(outline+11, "%3ld", (long)fstat_buf.st_nlink);
   sprintf(outline+15, "%4lo", (unsigned long)fstat_buf.st_uid);
   sprintf(outline+20, "%4lo", (unsigned long)fstat_buf.st_gid);
-  sprintf(outline+30, "%10ld", (long)fstat_buf.st_size);
+  sprintf(outline+30, "%10llu", (unsigned long long)fstat_buf.st_size);
 
   if (do_sectors == 0) {
-    sprintf(outline+30, "%10ld", (long)fstat_buf.st_size);
+    sprintf(outline+30, "%10llu", (unsigned long long)fstat_buf.st_size);
   } else {
-    sprintf(outline+30, "%10ld", (long)((fstat_buf.st_size+PAGE-1)/PAGE));
+    sprintf(outline+30, "%10llu", (unsigned long long)((fstat_buf.st_size+PAGE-1)/PAGE));
   }
 
   if( date_buf[1] >= 1 && date_buf[1] <= 12 )
