@@ -260,7 +260,7 @@ struct deferred_write {
 	struct deferred_write *next;
 	char           *table;
 	unsigned int    extent;
-	unsigned int    size;
+	off_t		size;
 	char           *name;
 	struct directory_entry *s_entry;
 	unsigned int    pad;
@@ -445,10 +445,10 @@ extern void scan_sparc_boot __PR((char *files));
 extern int make_sun_label __PR((void));
 
 /* write.c */
-extern int get_731 __PR((char *));
-extern int get_732 __PR((char *));
-extern int get_733 __PR((char *));
-extern int isonum_733 __PR((unsigned char *));
+extern unsigned int get_731 __PR((char *));
+extern unsigned int get_732 __PR((char *));
+extern unsigned int get_733 __PR((char *));
+extern unsigned int isonum_733 __PR((unsigned char *));
 extern void set_723 __PR((char *, unsigned int));
 extern void set_731 __PR((char *, unsigned int));
 extern void set_721 __PR((char *, unsigned int));
