@@ -59,10 +59,10 @@ extern char    *strdup(const char *);
 #define TF_ACCESS 4
 #define TF_ATTRIBUTES 8
 
-static int	isonum_711	__PR((unsigned char *p));
-static int	isonum_721	__PR((unsigned char *p));
-static int	isonum_723	__PR((unsigned char *p));
-static int	isonum_731	__PR((unsigned char *p));
+static unsigned int	isonum_711	__PR((unsigned char *p));
+static unsigned int	isonum_721	__PR((unsigned char *p));
+static unsigned int	isonum_723	__PR((unsigned char *p));
+static unsigned int	isonum_731	__PR((unsigned char *p));
 
 static	void	printasc	__PR((char *txt, unsigned char *p, int len));
 static	void	prbytes		__PR((char *txt, unsigned char *p, int len));
@@ -82,38 +82,17 @@ static int	merge_old_directory_into_tree __PR((struct directory_entry *,
 							struct directory *));
 static void	check_rr_relocation __PR((struct directory_entry * de));
 
-#ifdef	__STDC__
-static int
-isonum_711(unsigned char *p)
-#else
-static int
-isonum_711(p)
-	unsigned char	*p;
-#endif
+static unsigned int isonum_711(unsigned char *p)
 {
 	return (*p & 0xff);
 }
 
-#ifdef	__STDC__
-static int
-isonum_721(unsigned char *p)
-#else
-static int
-isonum_721(p)
-	unsigned char	*p;
-#endif
+static unsigned int isonum_721(unsigned char *p)
 {
 	return ((p[0] & 0xff) | ((p[1] & 0xff) << 8));
 }
 
-#ifdef	__STDC__
-static int
-isonum_723(unsigned char *p)
-#else
-static int
-isonum_723(p)
-	unsigned char	*p;
-#endif
+static unsigned int isonum_723(unsigned char *p)
 {
 #if 0
 	if (p[0] != p[3] || p[1] != p[2]) {
@@ -128,14 +107,7 @@ isonum_723(p)
 	return (isonum_721(p));
 }
 
-#ifdef	__STDC__
-static int
-isonum_731(unsigned char *p)
-#else
-static int
-isonum_731(p)
-	unsigned char	*p;
-#endif
+static unsigned int isonum_731(unsigned char *p)
 {
 	return ((p[0] & 0xff)
 		| ((p[1] & 0xff) << 8)
@@ -143,14 +115,7 @@ isonum_731(p)
 		| ((p[3] & 0xff) << 24));
 }
 
-#ifdef	__STDC__
-int
-isonum_733(unsigned char *p)
-#else
-int
-isonum_733(p)
-	unsigned char	*p;
-#endif
+unsigned int isonum_733(unsigned char *p)
 {
 	return (isonum_731(p));
 }
