@@ -34,6 +34,7 @@ static	char sccsid[] =
 #include <timedefs.h>
 #include <signal.h>
 #include <schily.h>
+#include <errno.h>
 
 #include <scg/scgcmd.h>
 #include <scg/scsireg.h>
@@ -1101,7 +1102,7 @@ read_generic(scgp, parmp, rfunc, rp, dfunc)
 		}
 		(*dfunc)(rp, Sbuf, addr, cnt);
 		if (filewrite(f, Sbuf, cnt * secsize) < 0) {
-			err = geterrno();
+			err = errno;
 			error("\n");
 			errmsgno(err, "Cannot write '%s'\n", filename);
 			break;
