@@ -101,13 +101,13 @@ LOCAL	char	*peername;
 LOCAL	char	*debug_name;
 LOCAL	FILE	*debug_file;
 
-#define	DEBUG(fmt)		if (debug_file) js_fprintf(debug_file, fmt)
-#define	DEBUG1(fmt,a)		if (debug_file) js_fprintf(debug_file, fmt, a)
-#define	DEBUG2(fmt,a1,a2)	if (debug_file) js_fprintf(debug_file, fmt, a1, a2)
-#define	DEBUG3(fmt,a1,a2,a3)	if (debug_file) js_fprintf(debug_file, fmt, a1, a2, a3)
-#define	DEBUG4(fmt,a1,a2,a3,a4)	if (debug_file) js_fprintf(debug_file, fmt, a1, a2, a3, a4)
-#define	DEBUG5(fmt,a1,a2,a3,a4,a5)	if (debug_file) js_fprintf(debug_file, fmt, a1, a2, a3, a4, a5)
-#define	DEBUG6(fmt,a1,a2,a3,a4,a5,a6)	if (debug_file) js_fprintf(debug_file, fmt, a1, a2, a3, a4, a5, a6)
+#define	DEBUG(fmt)		if (debug_file) fprintf(debug_file, fmt)
+#define	DEBUG1(fmt,a)		if (debug_file) fprintf(debug_file, fmt, a)
+#define	DEBUG2(fmt,a1,a2)	if (debug_file) fprintf(debug_file, fmt, a1, a2)
+#define	DEBUG3(fmt,a1,a2,a3)	if (debug_file) fprintf(debug_file, fmt, a1, a2, a3)
+#define	DEBUG4(fmt,a1,a2,a3,a4)	if (debug_file) fprintf(debug_file, fmt, a1, a2, a3, a4)
+#define	DEBUG5(fmt,a1,a2,a3,a4,a5)	if (debug_file) fprintf(debug_file, fmt, a1, a2, a3, a4, a5)
+#define	DEBUG6(fmt,a1,a2,a3,a4,a5,a6)	if (debug_file) fprintf(debug_file, fmt, a1, a2, a3, a4, a5, a6)
 
 EXPORT int
 main(argc, argv)
@@ -124,7 +124,7 @@ main(argc, argv)
 		argc--, argv++;
 	}
 	if (defltopen("/etc/default/rscsi") < 0) {
-		rscsierror(errno, errmsgstr(errno),
+		rscsierror(errno, strerror(errno),
 			"Remote configuration error: Cannot open /etc/default/rscsi");
 /*		rscsirespond(-1, errno);*/
 		exit(EX_BAD);
@@ -194,7 +194,7 @@ getpeer()
 static	char		buffer[MAXHOSTNAMELEN];
 
 	if (getpeername(STDIN_FILENO, &sa, &sasize) < 0) {
-		DEBUG1("rscsid: peername %s\n", errmsgstr(errno));
+		DEBUG1("rscsid: peername %s\n", strerror(errno));
 		return ("ILLEGAL_SOCKET");
 	} else {
 		s = (struct sockaddr_in *)&sa;
@@ -202,14 +202,14 @@ static	char		buffer[MAXHOSTNAMELEN];
 			return ("NOT_IP");
                
 #ifdef	HAVE_INET_NTOA
-		(void) js_snprintf(buffer, sizeof(buffer), "%s", inet_ntoa(s->sin_addr));
+		(void) snprintf(buffer, sizeof(buffer), "%s", inet_ntoa(s->sin_addr));
 #else
-		(void) js_snprintf(buffer, sizeof(buffer), "%x", s->sin_addr.s_addr);
+		(void) snprintf(buffer, sizeof(buffer), "%x", s->sin_addr.s_addr);
 #endif
 		DEBUG1("rscsid: peername %s\n", buffer);
 		he = gethostbyaddr((char *)&s->sin_addr.s_addr, 4, AF_INET);
 		if (he != NULL)
-			(void) js_snprintf(buffer, sizeof(buffer), "%s", he->h_name);
+			(void) snprintf(buffer, sizeof(buffer), "%s", he->h_name);
 		DEBUG1("rscsid: peername %s\n", buffer);
 		return (buffer);
 	}
@@ -429,7 +429,7 @@ openscsi()
 		 * XXX This is currently the only place where we use the
 		 * XXX extended error string.
 		 */
-		rscsierror(errno, errmsgstr(errno), errstr);
+		rscsierror(errno, strerror(errno), errstr);
 /*		rscsirespond(ret, errno);*/
 		return;
 	}
@@ -439,7 +439,7 @@ openscsi()
 		scg_target(scsi_ptr),
 		scg_lun(scsi_ptr));
 
-	ret = js_snprintf(rbuf, sizeof(rbuf), "A0\n%d\n%d\n%d\n%d\n",
+	ret = snprintf(rbuf, sizeof(rbuf), "A0\n%d\n%d\n%d\n%d\n",
 		scg_scsibus(scsi_ptr),
 		0,
 		scg_target(scsi_ptr),
@@ -712,7 +712,7 @@ sendcmd()
 		*(Uchar *)&scmd->scb,
 		scmd->sense_count);
 
-	ret = js_snprintf(rbuf, sizeof(rbuf), "A%d\n%d\n%d\n%d\n%d\n",
+	ret = snprintf(rbuf, sizeof(rbuf), "A%d\n%d\n%d\n%d\n%d\n",
 		n,
 		scmd->error,
 		scmd->ux_errno,
@@ -870,7 +870,7 @@ rscsirespond(ret, err)
 	int	err;
 {
 	if (ret < 0) {
-		rscsierror(err, errmsgstr(err), NULL);
+		rscsierror(err, strerror(err), NULL);
 	} else {
 		rscsireply(ret);
 	}
@@ -883,7 +883,7 @@ rscsireply(ret)
 	char	rbuf[CMD_SIZE];
 
 	DEBUG1("rscsid:>A %d\n", ret);
-	(void) js_snprintf(rbuf, sizeof(rbuf), "A%d\n", ret);
+	(void) snprintf(rbuf, sizeof(rbuf), "A%d\n", ret);
 	(void) _nixwrite(STDOUT_FILENO, rbuf, strlen(rbuf));
 }
 
@@ -901,7 +901,7 @@ rscsierror(err, str, xstr)
 		xlen = strlen(xstr) + 1;
 
 	DEBUG3("rscsid:>E %d (%s) [%s]\n", err, str, xstr?xstr:"");
-	n = js_snprintf(rbuf, sizeof(rbuf), "E%d\n%s\n%d\n", err, str, xlen);
+	n = snprintf(rbuf, sizeof(rbuf), "E%d\n%s\n%d\n", err, str, xlen);
 
 	if (xlen > 0 && ((xlen + n) <= sizeof(rbuf))) {
 		movebytes(xstr, &rbuf[n], xlen);
